/*******************************************************************************
********************************************************************************

   COPYRIGHT  2004, Advanced Illumination, Inc. 

   Contains confidential and proprietary information which may not be copied,
   disclosed or used by others except as expressly authorized in writing
   by Advanced Illumination.

   hostcmds.h     Host Command C header file

   About:         This module contains definitions for all host commands
                  handled by the command processor routines for the
                  AICONS01 project.

   Target CPU:    H8S/2215

   Written for:   Advanced Illumination, Inc.
                  24 Peavine Drive
                  Rochester, VT 05767
                  http://advancedillumination.com

   Contacts:      John Thrailkill
                  Phone:  (802) 767-3830
                  FAX:    (802) 767-3831
                  jthrailkill@advill.com

   Written by:    Rob Macklin
                  Microprocessor Designs, Inc.
                  65 Longmeadow Drive
                  PO Box 160
                  Shelburne, VT 05482
                  http://www.updesigns.com

   $Revision: 3 $

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
   $Log: /Advanced Illumination/Pulsar320/pc_src/MPDH8USB_TCP/hostcmds.h $
 * 
 * 3     8/21/08 1:59p Jpiet
 * Fixed length of get_repeat_data response
 * 
 * 2     8/20/08 9:02a Jpiet
 * Added repeat commands
 * 
 * 1     8/15/08 8:45a Jpiet
 * Initial check-in
 * 
 * 8     5/15/08 12:48p Rmack
 * Added 32-bit width commands as superset of existing command set.
 * 
 * 6     2/17/05 2:00p Rmack
 * Added command to control gate in continuous mode.
 * 
 * 5     1/06/05 2:48p Rmack
 * Added get_volts command.
 * 
 * 4     10/05/04 11:02a Rmack
 * Added command identifiers for new lighthead LED calculation functions.
 * 
 * 3     9/13/04 10:21a Rmack
 * Added commands for direct control of pulse outputs.
 * 
 * 2     8/24/04 8:03a Rmack
 * DTC based triggering of all four channels with  <  2usec delay.  Basic
 * TK_PULSE command interface implemented.
 * 
 * 1     3/30/04 3:31p Rmack
 *
********************************************************************************
*******************************************************************************/
#ifndef _HOSTCMDS_H
#define _HOSTCMDS_H


/* Definitions */
#define HOSTCMD_ASCII_CMD_MSK                    0x5F
#define HOSTCMD_ERRORFLAG                        '*'
#define HOSTCMD_ERRORSTRING                      "**"

/* Block format information */
enum {
   HOSTCMD_REPORT_INDEX,
   HOSTCMD_FUNCT_INDEX,
   HOSTCMD_HEADERSIZE
};

#define HOSTCMD_CSUM_SIZE                        1
#define HOSTCMD_BLOCK_HEADER_SIZE                6
#define HOSTCMD_BLOCK_SIZE                       ((USBDEFS_HID_LONG_REPORT_LEN & 0xFFFE) -      /* This value should be even! */ \
                                                 HOSTCMD_BLOCK_HEADER_SIZE - HOSTCMD_HEADERSIZE)

/* Command Identifiers */
#define HOSTCMD_ECHO_CMD                    0x00
#define HOSTCMD_VERSION_CMD                 0x01
#define HOSTCMD_STATUS_CMD                  0x02
#define HOSTCMD_DIAGS_CMD                   0x03
#define HOSTCMD_CALIBRATE_CMD               0x04
#define HOSTCMD_SPECIAL_CMD                 0x05
#define HOSTCMD_SETANOUT_CMD                0x20
#define HOSTCMD_GETANOUT_CMD                0x21
#define HOSTCMD_GETANIN_CMD                 0x24
#define HOSTCMD_GETVOLTS_CMD                0x25
#define HOSTCMD_SETDIGOUT_CMD               0x40
#define HOSTCMD_GETDIGOUT_CMD               0x41
#define HOSTCMD_GETDIGIN_CMD                0x42
#define HOSTCMD_WRITEMEM_CMD                0x50
#define HOSTCMD_READMEM_CMD                 0x51
#define HOSTCMD_WRITEMEMBLK_CMD             0x52
#define HOSTCMD_READMEMBLK_CMD              0x53
#define HOSTCMD_WRITEEEMEMBLK_CMD           0x54
#define HOSTCMD_READEEMEMBLK_CMD            0x55
#define HOSTCMD_EXECUTE_CMD                 0x56
#define HOSTCMD_SET_PULSE_CMD               0x80
#define HOSTCMD_GET_PULSE_CMD               0x81
#define HOSTCMD_SET_TRIG_MAP_CMD            0x82
#define HOSTCMD_GET_TRIG_MAP_CMD            0x83
#define HOSTCMD_SET_HV_SUPPLY_CMD           0x84
#define HOSTCMD_GET_HV_SUPPLY_CMD           0x85
#define HOSTCMD_SET_LV_SUPPLY_CMD           0x86
#define HOSTCMD_GET_LV_SUPPLY_CMD           0x87
#define HOSTCMD_TRIGGER_CMD                 0x88
#define HOSTCMD_SET_PULSE_OUT_CMD           0x89
#define HOSTCMD_GET_PULSE_OUT_CMD           0x8A
#define HOSTCMD_SET_GATE_MAP_CMD            0x8B
#define HOSTCMD_CALC_LED_TEMP_CMD           0x90
#define HOSTCMD_CALC_MAX_WIDTH_CMD          0x91
#define HOSTCMD_CALC_MAX_CURRENT_CMD        0x92
#define HOSTCMD_CALC_MAX_FREQ_CMD           0x93
#define HOSTCMD_CALC_SUPPLY_VOLTAGE_CMD     0x94

/* Extended 32-bit pulse width commands */
#define HOSTCMD_SET_PULSE_EX_CMD            0xA0
#define HOSTCMD_GET_PULSE_EX_CMD            0xA1
#define HOSTCMD_CALC_LED_TEMP_EX_CMD        0xA2
#define HOSTCMD_CALC_MAX_WIDTH_EX_CMD       0xA3
#define HOSTCMD_CALC_MAX_CURRENT_EX_CMD     0xA4
#define HOSTCMD_CALC_MAX_FREQ_EX_CMD        0xA5
#define HOSTCMD_CALC_SUPPLY_VOLTAGE_EX_CMD  0xA6
#define HOSTCMD_GET_IP_CMD                  0xA7
#define HOSTCMD_GET_MAC_CMD                 0xA8
#define HOSTCMD_SET_IP_CMD                  0xA9
#define HOSTCMD_SET_MAC_CMD                 0xAA
#define HOSTCMD_SET_REPEAT_CMD              0xAB
#define HOSTCMD_GET_REPEAT_CMD              0xAC



/* Length of data sent with each command */
#define HOSTCMD_ECHO_CMD_LEN                50
#define HOSTCMD_VERSION_CMD_LEN             0
#define HOSTCMD_STATUS_CMD_LEN              0
#define HOSTCMD_DIAGS_CMD_LEN               1
#define HOSTCMD_CALIBRATE_CMD_LEN           2
#define HOSTCMD_SPECIAL_CMD_LEN             6
#define HOSTCMD_SETANOUT_CMD_LEN            4
#define HOSTCMD_GETANOUT_CMD_LEN            2
#define HOSTCMD_GETANIN_CMD_LEN             2
#define HOSTCMD_GETVOLTS_CMD_LEN            2
#define HOSTCMD_SETDIGOUT_CMD_LEN           2
#define HOSTCMD_GETDIGOUT_CMD_LEN           1
#define HOSTCMD_GETDIGIN_CMD_LEN            1
#define HOSTCMD_WRITEMEM_CMD_LEN            6
#define HOSTCMD_READMEM_CMD_LEN             4
#define HOSTCMD_WRITEMEMBLK_CMD_LEN         (HOSTCMD_BLOCK_HEADER_SIZE + HOSTCMD_BLOCK_SIZE)
#define HOSTCMD_READMEMBLK_CMD_LEN          HOSTCMD_BLOCK_HEADER_SIZE
#define HOSTCMD_WRITEEEMEMBLK_CMD_LEN       (HOSTCMD_BLOCK_HEADER_SIZE + HOSTCMD_BLOCK_SIZE)
#define HOSTCMD_READEEMEMBLK_CMD_LEN        HOSTCMD_BLOCK_HEADER_SIZE
#define HOSTCMD_WRITEFLASHBLK_CMD_LEN       (HOSTCMD_BLOCK_HEADER_SIZE + HOSTCMD_BLOCK_SIZE)
#define HOSTCMD_READFLASHBLK_CMD_LEN        HOSTCMD_BLOCK_HEADER_SIZE
#define HOSTCMD_ERASEFLASHBLK_CMD_LEN       HOSTCMD_BLOCK_HEADER_SIZE
#define HOSTCMD_EXECUTE_CMD_LEN             4
#define HOSTCMD_SET_PULSE_CMD_LEN           9
#define HOSTCMD_GET_PULSE_CMD_LEN           1
#define HOSTCMD_SET_TRIG_MAP_CMD_LEN        3
#define HOSTCMD_GET_TRIG_MAP_CMD_LEN        1
#define HOSTCMD_SET_HV_SUPPLY_CMD_LEN       5
#define HOSTCMD_GET_HV_SUPPLY_CMD_LEN       1
#define HOSTCMD_SET_LV_SUPPLY_CMD_LEN       4
#define HOSTCMD_GET_LV_SUPPLY_CMD_LEN       0
#define HOSTCMD_TRIGGER_CMD_LEN             1
#define HOSTCMD_SET_PULSE_OUT_CMD_LEN       1
#define HOSTCMD_GET_PULSE_OUT_CMD_LEN       0
#define HOSTCMD_SET_GATE_MAP_CMD_LEN        3
#define HOSTCMD_CALC_LED_TEMP_CMD_LEN       7
#define HOSTCMD_CALC_MAX_WIDTH_CMD_LEN      5
#define HOSTCMD_CALC_MAX_CURRENT_CMD_LEN    3
#define HOSTCMD_CALC_MAX_FREQ_CMD_LEN       7
#define HOSTCMD_CALC_SUPPLY_VOLTAGE_CMD_LEN 7  

/* Extended 32-bit pulse width command lengths */
#define HOSTCMD_SET_PULSE_EX_CMD_LEN        11
#define HOSTCMD_GET_PULSE_EX_CMD_LEN        1
#define HOSTCMD_CALC_LED_TEMP_EX_CMD_LEN    9
#define HOSTCMD_CALC_MAX_WIDTH_EX_CMD_LEN   5
#define HOSTCMD_CALC_MAX_CURRENT_EX_CMD_LEN 5
#define HOSTCMD_CALC_MAX_FREQ_EX_CMD_LEN    9
#define HOSTCMD_CALC_SUPPLY_VOLTAGE_EX_CMD_LEN  9
#define HOSTCMD_SET_REPEAT_CMD_LEN          7
#define HOSTCMD_GET_REPEAT_CMD_LEN          1

/* Ethernet commands */                                                  
#define HOSTCMD_GET_IP_CMD_LEN              0
#define HOSTCMD_GET_MAC_CMD_LEN             0
#define HOSTCMD_SET_IP_CMD_LEN              12
#define HOSTCMD_SET_MAC_CMD_LEN             6

/* Length of data sent with each response */
#define HOSTCMD_ECHO_RSP_LEN                50
#define HOSTCMD_VERSION_RSP_LEN             20
#define HOSTCMD_STATUS_RSP_LEN              2
#define HOSTCMD_DIAGS_RSP_LEN               0
#define HOSTCMD_CALIBRATE_RSP_LEN           0
#define HOSTCMD_SPECIAL_RSP_LEN             4
#define HOSTCMD_SETANOUT_RSP_LEN            0
#define HOSTCMD_GETANOUT_RSP_LEN            2
#define HOSTCMD_GETANIN_RSP_LEN             2
#define HOSTCMD_GETVOLTS_RSP_LEN            4
#define HOSTCMD_SETDIGOUT_RSP_LEN           0
#define HOSTCMD_GETDIGOUT_RSP_LEN           1
#define HOSTCMD_GETDIGIN_RSP_LEN            1
#define HOSTCMD_WRITEMEM_RSP_LEN            0
#define HOSTCMD_READMEM_RSP_LEN             2
#define HOSTCMD_WRITEMEMBLK_RSP_LEN         0
#define HOSTCMD_READMEMBLK_RSP_LEN          HOSTCMD_BLOCK_SIZE
#define HOSTCMD_WRITEEEMEMBLK_RSP_LEN       0
#define HOSTCMD_READEEMEMBLK_RSP_LEN        HOSTCMD_BLOCK_SIZE
#define HOSTCMD_WRITEFLASHBLK_RSP_LEN       0
#define HOSTCMD_READFLASHBLK_RSP_LEN        HOSTCMD_BLOCK_SIZE
#define HOSTCMD_ERASEFLASHBLK_RSP_LEN       0
#define HOSTCMD_EXECUTE_RSP_LEN             0
#define HOSTCMD_SET_PULSE_RSP_LEN           0
#define HOSTCMD_GET_PULSE_RSP_LEN           9
#define HOSTCMD_SET_TRIG_MAP_RSP_LEN        0
#define HOSTCMD_GET_TRIG_MAP_RSP_LEN        3
#define HOSTCMD_SET_HV_SUPPLY_RSP_LEN       0
#define HOSTCMD_GET_HV_SUPPLY_RSP_LEN       4
#define HOSTCMD_SET_LV_SUPPLY_RSP_LEN       0
#define HOSTCMD_GET_LV_SUPPLY_RSP_LEN       4
#define HOSTCMD_TRIGGER_RSP_LEN             0
#define HOSTCMD_SET_PULSE_OUT_RSP_LEN       0
#define HOSTCMD_GET_PULSE_OUT_RSP_LEN       1
#define HOSTCMD_SET_GATE_MAP_RSP_LEN        0
#define HOSTCMD_CALC_LED_TEMP_RSP_LEN       4
#define HOSTCMD_CALC_MAX_WIDTH_RSP_LEN      2
#define HOSTCMD_CALC_MAX_CURRENT_RSP_LEN    4
#define HOSTCMD_CALC_MAX_FREQ_RSP_LEN       2
#define HOSTCMD_CALC_SUPPLY_VOLTAGE_RSP_LEN 4


/* Extended 32-bit pulse width response lengths */
#define HOSTCMD_SET_PULSE_EX_RSP_LEN        0
#define HOSTCMD_GET_PULSE_EX_RSP_LEN        11
#define HOSTCMD_CALC_LED_TEMP_EX_RSP_LEN    4
#define HOSTCMD_CALC_MAX_WIDTH_EX_RSP_LEN   4
#define HOSTCMD_CALC_MAX_CURRENT_EX_RSP_LEN 4
#define HOSTCMD_CALC_MAX_FREQ_EX_RSP_LEN    2
#define HOSTCMD_CALC_SUPPLY_VOLTAGE_EX_RSP_LEN  4
#define HOSTCMD_SET_REPEAT_RSP_LEN          0
#define HOSTCMD_GET_REPEAT_RSP_LEN          6

/* Ethernet commands */                                                  
#define HOSTCMD_GET_IP_RSP_LEN              12
#define HOSTCMD_GET_MAC_RSP_LEN             6
#define HOSTCMD_SET_IP_RSP_LEN              0
#define HOSTCMD_SET_MAC_RSP_LEN             0

#define HOSTCMD_ERROR_RSP_LEN               4


#define HOSTCMD_REPORT_ID_OFFSET                 0
#define HOSTCMD_CMD_ID_OFFSET                    1
#define HOSTCMD_RSP_ID_OFFSET                    1
#define HOSTCMD_CMD_DATA_OFFSET                  2
#define HOSTCMD_RSP_DATA_OFFSET                  2
#define HOSTCMD_FEATURE_DATA_OFFSET              1

/* Define usage values for reports */
#define HOSTCMD_SHORT_CMD_USAGE                  0xa6
#define HOSTCMD_LONG_CMD_USAGE                   0xa7
#define HOSTCMD_SHORT_RSP_USAGE                  0xa8
#define HOSTCMD_LONG_RSP_USAGE                   0xa9
#define HOSTCMD_FEATURE_USAGE                    0xaa

/* 
   Define Feature Report values that can be implemented
   by the firmware independent of the normal protocol.
*/
#define HOSTCMD_STARTLOADER_FEATURE              0x01
#define HOSTCMD_STARTAPPLICATION_FEATURE         0x02
#define HOSTCMD_RESET_FEATURE                    0x03


/* USB Communication specific definitions */
#define HOSTCMD_MANUFACTURER_STRING              1
#define HOSTCMD_PRODUCT_STRING                   2
#define HOSTCMD_SERIAL_NUMBER_STRING             3
#define HOSTCMD_FW_PARTNUMBER_STRING             4
#define HOSTCMD_HW_PARTNUMBER_STRING             5



#endif /* _HOSTCMDS_H */

