/*******************************************************************************
********************************************************************************

   COPYRIGHT  2004, Advanced Illumination, Inc. 

   Contains confidential and proprietary information which may not be copied,
   disclosed or used by others except as expressly authorized in writing
   by Advanced Illumination.

   tarmap.h       Microcomputer Target Map Header File

   About:         This module contains target specific definitions
                  for the AICONS01 project.

   Target CPU:    H8S/2215

   Written for:   Advanced Illumination, Inc.
                  24 Peavine Drive
                  Rochester, VT 05767
                  http://advancedillumination.com

   Contacts:      John Thrailkill
                  Phone:  (802) 767-3830
                  FAX:    (802) 767-3831
                  jthrailkill@advill.com

   Written by:    Rob Macklin
                  Microprocessor Designs, Inc.
                  65 Longmeadow Drive
                  PO Box 160
                  Shelburne, VT 05482
                  http://www.updesigns.com

   $Revision: 1 $

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
   $Log: /Advanced Illumination/Pulsar320/tar_src/H8App/tarmap.h $
 * 
 * 1     8/15/08 8:45a Jpiet
 * Initial check-in
 * 
 * 8     2/17/05 4:08p Rmack
 * Added definition for minimum VIN_SW voltage.
 * 
 * 7     10/29/04 8:06a Rmack
 * Updated attenuation values.
 * 
 * 6     9/21/04 11:57a Rmack
 * 
 * 5     8/24/04 8:03a Rmack
 * DTC based triggering of all four channels with  <  2usec delay.  Basic
 * TK_PULSE command interface implemented.
 * 
 * 4     8/11/04 4:40p Jwayg
 * Final check-in under JWayg name, code currently setup to run LED tests.
 * 
 * 3     7/01/04 10:30a Jwayg
 * Last code release before transfer of source files to new programmer.
 * 
 * 2     5/17/04 10:57a Jwayg
 * Common Files for Initial Running Version of S1000 
 * 
 * 1     3/30/04 3:32p Rmack
 *
********************************************************************************
*******************************************************************************/
#ifndef _TARMAP_H
#define _TARMAP_H

#ifndef WIN32
#include "h8port.h"
#endif
/*
    Define base address of RAM start/end address, FLASH start/end address, 
    external EEPROM base address and  start/end address
   Note: Lengths are in bytes 
*/
#define FLASH_START_ADDR           0x0000
#define FLASH_LEN                  0x40000

#define EXTEEPROM_MFG_START_ADDR       0x0000
#define EXTEEPROM_MFG_SIZE             0x0200
#define EXTEEPROM_USR_START_ADDR       (EXTEEPROM_MFG_START_ADDR + EXTEEPROM_MFG_SIZE)
#define EXTEEPROM_USR_SIZE             0x200
#define EXTEEPROM_LH1_START_ADDR       (EXTEEPROM_USR_START_ADDR + EXTEEPROM_USR_SIZE)
#define EXTEEPROM_LH1_SIZE             0x0090
#define EXTEEPROM_LH2_START_ADDR       (EXTEEPROM_LH1_START_ADDR + EXTEEPROM_LH1_SIZE)
#define EXTEEPROM_LH2_SIZE             0x0090
#define EXTEEPROM_USR32K_START_ADDR    (EXTEEPROM_LH2_START_ADDR + EXTEEPROM_LH2_SIZE)
#define EXTEEPROM_USR32K_SIZE          0x1000

#define LCD_BASE_ADDR                  0x200000
#define EXT1_BASE_ADDR                 0x400000
#define EXT2_BASE_ADDR                 0x600000

//#define EXTEEPROM_USR_START_ADDR       (EXTEEPROM_MFG_START_ADDR + EXTEEPROM_MFG_SIZE)
//#define EXTEEPROM_USR_SIZE             0x0200 
//#define EXTEEPROM_SIZE                 0x0200 
    

/*
   Platform-specific CPU Port/Bit Defintions
*/

/*************** Pulsar 320 Definitions *******/

/* Definitions for digital inputs */
#define TRIG1                      IOPF0_BIT
#define TRIG1_INPORT               PORTF
#define TRIG2                      IOPF3_BIT
#define TRIG2_INPORT               PORTF
#define H8_PHI                     IOPF7_BIT
#define H8_PHI_INPORT              PORTF

#define EZPQ                       IOP31_BIT
#define EZPQ_INPORT                PORT3
#define USBDETECTGPIO              IOP34_BIT
#define USBDETECTGPIO_INPORT       PORT3

/*NOTE: The buttons are assumed to be on a single port in tk_user */
#define PB0                        IOP70_BIT
#define PB0_INPORT                 PORT7
#define PB1                        IOP71_BIT
#define PB1_INPORT                 PORT7
#define PB2                        IOP73_BIT
#define PB2_INPORT                 PORT7
#define PB3                        IOP74_BIT
#define PB3_INPORT                 PORT7

#define LH_DATA_IN1                IOPE1_BIT
#define LH_DATA_IN1_INPORT         PORTE
#define LH_DATA_IN2                IOPE3_BIT
#define LH_DATA_IN2_INPORT         PORTE

#define MCF2H8IRQ_                 IOPB2_BIT
#define MCF2H8IRQ__INPORT          PORTB

#define LHDET1                     IOPA0_BIT
#define LHDET1_INPORT              PORTA
#define LHDET2                     IOPA3_BIT
#define LHDET2_INPORT              PORTA

#define MCF2H8DATA                 IOP12_BIT
#define MCF2H8DATA_INPORT          PORT1
#define MCFRSTO_                   IOP17_BIT
#define MCFRSTO__INPORT            PORT1

#define USBDETECT                  BIT7
#define USBDETECT_INPORT           UTSTR1

/* Definitions for digital outputs */
/* H8 Port definitions */
#define MCFSS_                     IOPF1_BIT
#define MCFSS__INPORT              PORTF
#define MCFSS__OUTPORT             PFDR
#define TP28                       IOPF5_BIT
#define TP28_INPORT                PORTF
#define TP28_OUTPORT               PFDR
#define TP30                       IOPF6_BIT
#define TP30_INPORT                PORTF
#define TP30_OUTPORT               PFDR

#define EZPD                       IOP30_BIT
#define EZPD_INPORT                PORT3
#define EZPD_OUTPORT               P3DR
#define EZPCK                      IOP32_BIT
#define EZPCK_INPORT               PORT3
#define EZPCK_OUTPORT              P3DR

#define PWMCH2                     IOP72_BIT
#define PWMCH2_INPORT              PORT7
#define PWMCH2_OUTPORT             P7DR

#define LH_DATA_OUT1               IOPE0_BIT
#define LH_DATA_OUT1_INPORT        PORTE
#define LH_DATA_OUT1_OUTPORT       PEDR
#define LH_DATA_OUT2               IOPE2_BIT
#define LH_DATA_OUT2_INPORT        PORTE
#define LH_DATA_OUT2_OUTPORT       PEDR
#define LH_DATA_OUT_TRIS           IOPE4_BIT
#define LH_DATA_OUT_TRIS_INPORT    PORTE
#define LH_DATA_OUT_TRIS_OUTPORT   PEDR
#define CH1SIG2EN                  IOPE5_BIT
#define CH1SIG2EN_INPORT           PORTE
#define CH1SIG2EN_OUTPORT          PEDR
#define CH2SIG2EN                  IOPE6_BIT
#define CH2SIG2EN_INPORT           PORTE
#define CH2SIG2EN_OUTPORT          PEDR
#define H82MCFRST                  IOPE7_BIT
#define H82MCFRST_INPORT           PORTE
#define H82MCFRST_OUTPORT          PEDR

#define H8U2TXD                    IOPA1_BIT
#define H8U2TXD_INPORT             PORTA
#define H8U2TXD_OUTPORT            PADR
#define H8U2RXD                    IOPA2_BIT
#define H8U2RXD_INPORT             PORTA
#define H8U2RXD_OUTPORT            PADR

#define OLATOE_                    IOPB0_BIT
#define OLATOE__INPORT             PORTB
#define OLATOE__OUTPORT            PBDR
#define BCKLGHTCNTRL               IOPB1_BIT
#define BCKLGHTCNTRL_INPORT        PORTB
#define BCKLGHTCNTRL_OUTPORT       PBDR
#define H82MCFDATA                 IOPB3_BIT
#define H82MCFDATA_INPORT          PORTB
#define H82MCFDATA_OUTPORT         PBDR
#define I2CSCL                     IOPB4_BIT
#define I2CSCL_INPORT              PORTB
#define I2CSCL_OUTPORT             PBDR
#define I2CSDA                     IOPB5_BIT
#define I2CSDA_INPORT              PORTB
#define I2CSDA_OUTPORT             PBDR
#define I2CSDA_DIRPORT             PBDDR
#define RED_LED_ON                 IOPB6_BIT
#define RED_LED_ON_INPORT          PORTB
#define RED_LED_ON_OUTPORT         PBDR
#define YLW_LED_ON                 IOPB7_BIT
#define YLW_LED_ON_INPORT          PORTB
#define YLW_LED_ON_OUTPORT         PBDR

#define CH1PULS_                   IOP10_BIT
#define CH1PULS__INPORT            PORT1
#define CH1PULS__OUTPORT           P1DR
#define TP153                      IOP11_BIT
#define TP153_INPORT               PORT1
#define TP153_OUTPORT              P1DR
#define H82MCFIRQ_                 IOP13_BIT
#define H82MCFIRQ__INPORT          PORT1
#define H82MCFIRQ__OUTPORT         P1DR
#define PWMCH1                     IOP16_BIT
#define PWMCH1_INPORT              PORT1    
#define PWMCH1_OUTPORT             P1DR     
#define CH2PULS_                   IOP14_BIT 
#define CH2PULS__INPORT            PORT1     
#define CH2PULS__OUTPORT           P1DR      

#define EZPCS_                     IOPG0_BIT
#define EZPCS__INPORT              PORTG
#define EZPCS__OUTPORT             PGDR
#define LCDCS_                     IOPG3_BIT
#define OLATCS0_                   IOPG2_BIT
#define OLATCS1_                   IOPG1_BIT

/* Define initial state of P1DDR */
/* This is used by the I2C primitives because they need to */
/* quickly modifiy the direction of the I2CSDA signal      */
/* without overhead.  This initial setting sets the I2CSDA */
/* pin to input mode by default and the I2C primitive sets */
/* the pin to output mode as needed */
#define I2C_GPIO_DIR_PORT_INIT_STATE   ((UINT8_T)IODIG_PBDDR_INITIAL_STATE )

#define USBPUON                    IOP36_BIT
#define USBPUON_INPORT             PORT3
#define USBPUON_OUTPORT            P3DR


/* External output port definitions */
#define EXT_OUT1_PORT              EXT1_BASE_ADDR
#define SINGL_DIFF_TRIG1           BIT0
#define SINGL_DIFF_TRIG2           BIT1
#define FBSELCH1                   BIT2
#define FBSELCH2                   BIT3
#define CH1CAP1_                   BIT4
#define CH1CAP2_                   BIT5
#define CH2CAP1_                   BIT6
#define CH2CAP2_                   BIT7

#define EXT_OUT2_PORT              EXT2_BASE_ADDR
#define BLEED_CAP_DIS              BIT0
#define HV_RUN                     BIT1
#define _10VSWON                   BIT2
#define MUXSEL0                    BIT3
#define MUXSEL1                    BIT4
#define MUXSEL2                    BIT5
#define MUXEN_                     BIT6

/* Voltage required to detect that VIN_SW is on */
#define VIN_SW_MIN_ON_VOLTS        ((FLOAT32_T) 10.0)

/* Voltage Reference values and ADC count information used for conversions to real units */
#define ADC_VREF                    ((FLOAT32_T) 3.0)
#define ADC_MAX_COUNTS              1024
#define DAC_VREF                    ADC_VREF
#define DAC_MAX_COUNTS              256
#define EXT_DAC_VREF                ((FLOAT32_T) 3.0)
#define EXT_DAC_MAX_COUNTS          1024

/* Voltage divider attenuations for analog inputs */
#define POS_5VDMON_RBOTTOM          100.0
#define POS_VHVMON_RBOTTOM          39.2
#define POS_VIN_SWMON_RBOTTOM       39.2
#define POS_10VDMON_RBOTTOM         17.4


#define CH1_CURRSENS_ATTEN       1.0
#define CH2_CURRSENS_ATTEN       1.0
#define POS_5VDMON_ATTEN         (POS_5VDMON_RBOTTOM       / (POS_5VDMON_RBOTTOM       +  100.0 ))
#define POS_VHVMON_ATTEN         (POS_VHVMON_RBOTTOM       / (POS_VHVMON_RBOTTOM       + 1500.0 ))
#define POS_VIN_SWMON_ATTEN      (POS_VIN_SWMON_RBOTTOM    / (POS_VIN_SWMON_RBOTTOM    + 1500.0 ))
#define POS_10VDMON_ATTEN        (POS_10VDMON_RBOTTOM      / (POS_10VDMON_RBOTTOM      +  100.0 ))
#define POS_CH1SIG1_1MON_ATTEN   1.0
#define POS_CH1SIG1_2MON_ATTEN   1.0
#define POS_CH2SIG1_1MON_ATTEN   1.0
#define POS_CH2SIG1_2MON_ATTEN   1.0
#define POS_DGNDMON_ATTEN        1.0

                       
/* Map original code port definitions to Pulsar320 defintions */
#define MUXSELA                        MUXSEL0
#define MUXSELB                        MUXSEL1
#define MUXSELC                        MUXSEL2
#define POS_V_HV_STRINGMON_ATTEN       POS_VHVMON_ATTEN
#define POS_10VMON_ATTEN               POS_10VDMON_ATTEN
#define POS_5VMON_ATTEN                POS_5VDMON_ATTEN
#define AGND_ATTEN                     POS_DGNDMON_ATTEN


#endif  /* _TARMAP_H */
