/*******************************************************************************
********************************************************************************

   COPYRIGHT  2005, Advanced Illumination, Inc. 

   Contains confidential and proprietary information which may not be copied,
   disclosed or used by others except as expressly authorized in writing
   by Advanced Illumination.

   PulsarAPI.cpp  Source code for the High Level Application Interface for the 
                  S1000 Strobe Controller.

   About:         This module contains the implementation of the application level
                  DLL support functions for the S1000 Strobe Controller.

   Target:        Win32 Compatible

   Written for:   Advanced Illumination, Inc.
                  24 Peavine Drive
                  Rochester, VT 05767
                  http://advancedillumination.com

   Contacts:      John Thrailkill
                  Phone:  (802) 767-3830
                  FAX:    (802) 767-3831
                  jthrailkill@advill.com

   Written by:    Rob Macklin
                  Microprocessor Designs, Inc.
                  65 Longmeadow Drive
                  PO Box 160
                  Shelburne, VT 05482
                  http://www.updesigns.com

   $Revision: 3 $

--------------------------------------------------------------------------------
   $Log: /Advanced Illumination/Pulsar320/pc_src/PulsarAPI/PulsarAPI.cpp $
 * 
 * 3     8/22/08 3:06p Jpiet
 * Made additions for repeat mode
 * 
 * 2     8/15/08 4:26p Jpiet
 * 
 * 1     8/15/08 2:31p Jpiet
 * 
 * 5     5/21/08 11:19a Rmack
 * Support for 100 ms pulse widths.
 * 
 * 4     5/02/05 8:52a Rmack
 * Dual pulse mode triggers, added new command for lighthead information,
 * separate gated continuous mode of operation.
 * 
 * 3     2/24/05 8:56a Rmack
 * Fixed problem with DLL name in get_version function.
 * 
 * 2     2/23/05 5:17p Rmack
 * Supports channel configuration validation, and mixed mode operation.
 * 
 * 1     1/04/05 7:44a Rmack
 * 
********************************************************************************
*******************************************************************************/
#include "stdafx.h"
#include "compiler.h"
#include "pc_error.h"
#include "tk_time.h"
#include "MPDH8USB_TCP.h"
#include "PulsarAPI.h"
#include <stdio.h>
#include <oleauto.h>
/* The following include files are shared with the firmware.  The pragma is used
to ensure the byte alignment of structures matches the H8.  */
#pragma pack(2)
#include "ap_header.h"
#include "tk_crc.h"
#include "tk_pulse.h"
#include "speccmds.h"
#include "tarerror.h"
#include "tarmap.h"
#pragma pack()

#define PULSARAPI_GET_NUM_TRIG_M() 2

/* 
   This pragma is required to force the variables into the same data segment
   so that each instance of the DLL sees the same variable.  Other global
   variables declared outside this pragma block get new copies created
   for every instance of the DLL.
*/
#pragma data_seg(".DLLDAT")
UINT32_T dll_instance_count = 0;
char DLLPath[MAX_PATH] = {""};
API_CHAN_CONFIG_STRUCT_T test_config_data = {1,2,3,4,5,6,7};
#pragma data_seg()
#pragma comment(linker,"/SECTION:.DLLDAT,RWS")


BOOL APIENTRY DllMain( HANDLE hModule, 
                       DWORD  ul_reason_for_call, 
                       LPVOID lpReserved
					 )
{
    switch (ul_reason_for_call)
	{
		case DLL_PROCESS_ATTACH:
         /* Initialize time toolkit functions */
         TKTIME_INIT_M();
         break;
		case DLL_THREAD_ATTACH:
         break;
		case DLL_THREAD_DETACH:
         break;
		case DLL_PROCESS_DETACH:
			break;
    }
    return TRUE;
}

/****************************************************************************
   api_get_dll_version()

   Returns the current version number of this software.

   Inputs:     None

   Outputs:    None
   
   Returns:    UINT16_T    ver_info    High byte is major version number
                                       Low byte is minor version number

****************************************************************************/
PULSAR_API UINT16_T __stdcall api_get_dll_version(void)
{
   char *appname = "PulsarAPI.dll";
   UINT16_T retval = 0;
   DWORD dummy;
   VS_FIXEDFILEINFO * FixedInfo;
   unsigned int FixedInfoLen;

   /* Get the size of the version information */
   int VersionInfoSize = GetFileVersionInfoSize(appname,&dummy);
   if (!VersionInfoSize)
      return 0;

   /* Allocate memory to hold version information */
   char *VersionBuf = new char[VersionInfoSize];
   if (!VersionBuf)
      return 0;

   /* Load version information into buffer */
   if (GetFileVersionInfo(appname,dummy,VersionInfoSize,VersionBuf)) {

      /* Extract file version information from buffer */
      VerQueryValue(VersionBuf,"\\",(void **) &FixedInfo,&FixedInfoLen);

      /* Encode version info into UINT16_T */
      retval = (UINT16_T) FixedInfo->dwFileVersionMS;
      retval <<= 8;
      retval |= (FixedInfo->dwFileVersionLS & 0xFF);
   }

   /* Free allocated memory */
   delete [] VersionBuf;

   /* Return version number */
   return retval;
}

/****************************************************************************
   api_get_error_name

   About:      Returns the name of the error associated with the code

   Inputs:     ERRCODE_T   ecode       Code to be looked up
               UINT16_T    namelen     Maximum length of name string

   Outputs:    char *      nameptr     Location to place name string

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
//PULSAR_API ERRCODE_T __stdcall api_get_error_name(ERRCODE_T ecode,char * nameptr,UINT16_T namelen)
PULSAR_API ERRCODE_T __stdcall api_get_error_name(ERRCODE_T ecode,char * nameptr,UINT16_T namelen)
{
	ERRCODE_T errcode;
	char tempStr[400] ;
	int i;
	errcode =  tkcmdset_get_error_name(ecode,tempStr,400);
	//Now copy returned string
	strncpy(nameptr, tempStr, namelen);
	//Now pad rest with spaces
	for(i=strlen(nameptr)+1;i<namelen;i++)
	{
		nameptr[i] = 0x20;
	}

	return(errcode);
}

/****************************************************************************
   api_get_error_text

   About:      Returns the text description of the error associated with the code

   Inputs:     ERRCODE_T   ecode       Code to be looked up
               UINT16_T    namelen     Maximum length of text description string

   Outputs:    char *      nameptr     Location to place text description string

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_error_text(ERRCODE_T ecode,char * textptr,UINT16_T textlen)
{
	ERRCODE_T errcode;
	char tempStr[400] ;
	int i;
	errcode =  tkcmdset_get_error_text(ecode,tempStr,400);
	//Now copy returned string
	strncpy(textptr, tempStr, textlen);
	//Now pad rest with spaces
	for(i=strlen(textptr)+1;i<textlen;i++)
	{
		textptr[i] = 0x20;
	}

	return(errcode);
}


/****************************************************************************
   api_init

	FOR USB CONNECTIONS ONLY - SEE API_CONNECT FOR TCP/IP CONNECTIONS

   About:      Initializes the connection to a specific Pulsar

   Inputs:     UINT8_T     port         Identifier for device
               INT8_T *    product_name Name of USB device to open
			   INT8_T *	   serial_num	Serial number of device to open

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_init(UINT8_T port, INT8_T * product_name, INT8_T * serial_num)
{
	//jdp temp return tkcmdset_init_ex(port,product_name, serial_num);
	ERRCODE_T ecode;
	UINT8_T macaddr[] = {00,0x22,0xFE,00,00,0x44};
	ecode = tkcmdset_init_ex(port,product_name, serial_num);
	//ecode = tkcmdset_set_mac(port, macaddr);
   return ecode;
}

/****************************************************************************
   api_connect

   About:      Initializes the connection to a specific Pulsar

   Inputs:     UINT8_T     port        Identifier for device
               INT8_T *    product_name Name of USB device to open
			   INT8_T *	   ip_addr		IP address of device to open

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_connect(UINT8_T port, INT8_T * product_name, INT8_T * ip_addr)
{
   return tkcmdset_connect(port,product_name, ip_addr);
}


/****************************************************************************
   api_get_pulsar_version

   About:      Reads firmware version, hardware version, and serial number
               Each string can be up to 32 characters long.

   Inputs:     UINT8_T     port        Identifier for device

   Outputs:    INT8_T *    fw_version  Firmware version
               INT8_T *    hw_version  Hardware version
               INT8_T *    serial_num  Serial number

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_pulsar_version(UINT8_T port, INT8_T * fw_version, INT8_T * hw_version, INT8_T * serial_num)
{
   ERRCODE_T ecode;

   /* Initialize pointers to empty strings */
   *fw_version = NULL;
   *hw_version = NULL;
   *serial_num = NULL;

   /* Get firmware version */
   if (ecode = tkcmdset_fw_version(port,(UINT8_T *) fw_version))
   {
   }
   /* Get hardware version */
   else if (ecode = tkcmdset_hw_version(port,(UINT8_T *) hw_version))
   {
   }
   /* Get serial number */
   else if (ecode = tkcmdset_serial_number(port,(UINT8_T *) serial_num))
   {
   }

   return(ecode);
}

/****************************************************************************
   api_get_pulsar_ipaddr

   About:      Reads iip configuration settings from the device
               Each string can be up to 32 characters long.

   Inputs:     UINT8_T     port        Identifier for device

   Outputs:    INT8_T *    ip_addr	   IP Address
               INT8_T *    subnet	   Subnet Mask
               INT8_T *    gateway	   Gateway
               INT8_T *    mac_addr	   Hardware MAC address

   Returns: ERRCODE_T   ecode          Status of command
                                          Zero if successful,
                                          Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_pulsar_ipaddr(UINT8_T port, INT8_T * ip_addr, INT8_T * subnet, INT8_T * gateway, INT8_T * mac_addr)
{
   ERRCODE_T ecode;
   UINT32_T ipNumber;
   UINT32_T subnetNumber;
   UINT32_T gatewayNumber;
   UINT8_T macNumber[7];

   /* Initialize pointers to empty strings */
   *ip_addr = NULL;
   *subnet = NULL;
   *gateway = NULL;

   /* Get firmware version */
   if (ecode = tkcmdset_get_ip(port,&ipNumber, &subnetNumber, &gatewayNumber))
   {
   }
   else if(ecode = tkcmdset_get_mac(port, macNumber))
   {
   }
   else
   {
	   sprintf(ip_addr, "%d.%d.%d.%d", (ipNumber>>24)&0xFF,(ipNumber>>16)&0xFF,(ipNumber>>8)&0xFF,ipNumber&0xFF);
	   sprintf(subnet, "%d.%d.%d.%d", (subnetNumber>>24)&0xFF,(subnetNumber>>16)&0xFF,(subnetNumber>>8)&0xFF,subnetNumber&0xFF);
	   sprintf(gateway, "%d.%d.%d.%d", (gatewayNumber>>24)&0xFF,(gatewayNumber>>16)&0xFF,(gatewayNumber>>8)&0xFF,gatewayNumber&0xFF);
	   sprintf(mac_addr, "%02X:%02X:%02X:%02X:%02X:%02X", macNumber[0],macNumber[1],macNumber[2],macNumber[3],macNumber[4],macNumber[5]);
   }
   return(ecode);
}

/****************************************************************************
   api_get_pulsar_ipaddr

   About:      Reads iip configuration settings from the device
               Each string can be up to 32 characters long.

   Inputs:     UINT8_T     port        Identifier for device

   Outputs:    INT8_T *    ip_addr	   IP Address
               INT8_T *    subnet	   Subnet Mask
               INT8_T *    gateway	   Gateway
               INT8_T *    mac_addr	   Hardware MAC address

   Returns: ERRCODE_T   ecode          Status of command
                                          Zero if successful,
                                          Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_set_pulsar_ipaddr(UINT8_T port, INT8_T * ip_addr, INT8_T * subnet, INT8_T * gateway)
{
   ERRCODE_T ecode;
   UINT32_T ipNumber;
   UINT32_T subnetNumber;
   UINT32_T gatewayNumber;
   UINT8_T tempByte[7];

   /* Set ip settings */
   sscanf(ip_addr, "%d.%d.%d.%d",&tempByte[0],&tempByte[1],&tempByte[2],&tempByte[3]);
   ipNumber = tempByte[0]<<24 | tempByte[1]<<16 |tempByte[2]<<8 | tempByte[3];
   sscanf(subnet, "%d.%d.%d.%d",&tempByte[0],&tempByte[1],&tempByte[2],&tempByte[3]);
   subnetNumber = tempByte[0]<<24 | tempByte[1]<<16 |tempByte[2]<<8 | tempByte[3];
   sscanf(gateway, "%d.%d.%d.%d",&tempByte[0],&tempByte[1],&tempByte[2],&tempByte[3]);
   gatewayNumber = tempByte[0]<<24 | tempByte[1]<<16 |tempByte[2]<<8 | tempByte[3];

   if (ecode = tkcmdset_set_ip(port,ipNumber, subnetNumber, gatewayNumber))
   {
   }
   return(ecode);
}

/****************************************************************************
   api_get_status

   About:      Reads status information from the device

   Inputs:     UINT8_T     port        Identifier for device

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_status(UINT8_T port)
{
   ERRCODE_T ecode;
   UINT16_T  status;

   if (ecode = tkcmdset_status(port,&status))
   {
   }
   else
   {
      ecode = status;
   }

   return(ecode);
}


/****************************************************************************
   api_run_diags

   About:      Runs one or all of the built in diagnostics

   Inputs:     UINT8_T     port        Identifier for device
               UINT8_T     test_num    Desired test number or FF for all

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_run_diags(UINT8_T port, UINT8_T test_num)
{
   return tkcmdset_run_diags(port,test_num);
}



/****************************************************************************
   api_get_channel_config

   About:      Gets the configuration data for one drive channel

   Inputs:     UINT8_T     port        Identifier for device
               UINT8_T     chan        Identifier for drive channel
               UINT8_T     type        Identifier for which data to get
               
   Outputs:    API_CHAN_CONFIG_STRUCT_T *  config_data
                                       Active channel configuration data

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_channel_config(UINT8_T port, UINT8_T chan, UINT8_T type,
                                               API_CHAN_CONFIG_STRUCT_T *  config_data)
{
   ERRCODE_T ecode = E_SUCCESS;
   APHEADER_CONFIG_STRUCT_T config_info;
   UINT8_T i;
   UINT8_T ci_index;
   UINT8_T tkchan;
   UINT32_T out_param;
   UINT32_T width;
   UINT16_T delay;
   UINT32_T offtime;
   UINT16_T pulse_cnt;
   FLOAT32_T current;
   UINT8_T mode;
   UINT8_T trigger;
   UINT8_T rising;

   /* Validate channel number */
   if ((chan != API_CHAN_1) && (chan != API_CHAN_2) )
   {
      ecode = API_INVALID_CHAN_ERR;
   }
   /* Get default channel configuration data */
   else if (type == API_CHAN_CONFIG_DEFAULT)
   {
      /* Read the existing data from EEPROM */
      if (ecode = tkcmdset_read_eemem_block(port,
                                            APHEADER_CONFIG_DATA_ADDRESS,
                                            (UINT8_T *) &config_info,
                                            sizeof(config_info)))
      {
      }
      /* Validate structure data */
      else if (APHEADER_CONFIG_INFO_VALID_M(&config_info))
      {
         /* Translate the channel to the index into the configuration information */
         switch (chan)
         {
         case API_CHAN_1:   ci_index = 0;    break;
         case API_CHAN_2:   ci_index = 1;    break;
         }

         /* Translate the operating mode */
         switch (config_info.defaults[ci_index].mode)
         {
         case TKPULSE_PULSE_MODE:            config_data->mode = API_MODE_PULSED;             break;
         case TKPULSE_REPEAT_MODE:           config_data->mode = API_MODE_REPEAT;             break;
         case TKPULSE_TIMING_BYPASS_MODE:    config_data->mode = API_MODE_TIMING_BYPASS;      break;
         case TKPULSE_INTERNAL_TRIG_MODE:    config_data->mode = API_MODE_INTERNAL_TRIGGER;   break;
         }

         /* Translate the trigger info */
         switch(config_info.defaults[ci_index].trigger)
         {
         case TKPULSE_TRIG1:  config_data->trigger = API_TRIG_1;     break;
         case TKPULSE_TRIG2:  config_data->trigger = API_TRIG_2;     break;
         default:             config_data->trigger = API_TRIG_NONE;  break;
         }

         /* Store the rest of the information in the application's structure */
         config_data->rising  = config_info.defaults[ci_index].trigger_edge;
         config_data->current = SWAP_FLOAT32_M(config_info.defaults[ci_index].current);

         {
            config_data->width      = SWAP_UINT32_M(config_info.defaults[ci_index].width);
            config_data->delay      = SWAP_UINT16_M(config_info.defaults[ci_index].delay);
            config_data->offtime    = SWAP_UINT32_M(config_info.defaults[ci_index].offtime);
            config_data->repeat_cnt = SWAP_UINT16_M(config_info.defaults[ci_index].pulse_cnt);
         }
      }
      /* Invalid structure */
      else
      {
         ecode = API_INVALID_CONFIG_CRC_ERR;
      }
   }
   /* Get active channel configuration data */
   else if (type == API_CHAN_CONFIG_ACTIVE)
   {
      /* Translate channel identifier */
      switch(chan)
      {
      case API_CHAN_1:   tkchan = TKPULSE_CHAN1;   break;
      case API_CHAN_2:   tkchan = TKPULSE_CHAN2;   break;
      }

      /* Get pulse information */
      if (ecode = tkcmdset_get_pulse(port, tkchan, &width, &delay, &current))
      {
      }
      else if (ecode = tkcmdset_get_repeat(port, tkchan, &offtime, &pulse_cnt))
      {
      }
      /* Get mode information */
      else if (ecode = tkcmdset_special(port,SPECCMD_GET_CHAN_MODE_CMD,tkchan,&out_param))
      {
      }
      else
      {
         /* Translate the operating mode information */
         switch((UINT8_T) out_param)
         {
         case TKPULSE_PULSE_MODE:            mode = API_MODE_PULSED;             break;
         case TKPULSE_REPEAT_MODE:           mode = API_MODE_REPEAT;             break;
         case TKPULSE_TIMING_BYPASS_MODE:    mode = API_MODE_TIMING_BYPASS;      break;
         case TKPULSE_INTERNAL_TRIG_MODE:    mode = API_MODE_INTERNAL_TRIGGER;   break;
		 default: ecode = API_INVALID_CONFIG_TYPE_ERR; break;
         }

		 if(ecode == 0)
		 {
			 /* Determine trigger mapping */
			 trigger = 0;
			 for (i = 0; i < PULSARAPI_GET_NUM_TRIG_M(); i++)
			 {
				if (ecode = tkcmdset_get_trigger_map(port, (TKPULSE_TRIG1 << i), &chan, &rising))
				{
				   break;
				}
				/* Check if the specified channel associated with this trigger */
				else if ((chan & tkchan) != 0)
				{
				   /* Translate the active trigger identifier */
				   switch (TKPULSE_TRIG1 << i)
				   {
				   case TKPULSE_TRIG1:   trigger = API_TRIG_1;   break;
				   case TKPULSE_TRIG2:   trigger = API_TRIG_2;   break;
				   }
	               
				   break;
				}
			 }

			 /* Build the return structure information */
			 config_data->trigger = trigger;
			 config_data->rising = rising;
			 config_data->mode = mode;
			 config_data->current = current;

			 {
				config_data->width = width;
				config_data->delay = delay;
				config_data->offtime = offtime;
				config_data->repeat_cnt = pulse_cnt;
			 }
		 }
      }
   }
   /* Unknown type */
   else
   {
      ecode = API_INVALID_CONFIG_TYPE_ERR;
   }

   return(ecode);
}



/****************************************************************************
   api_set_channel_config

   About:      Sets the configuration data for one drive channel

   Inputs:     UINT8_T     port        Identifier for device
               UINT8_T     chan        Identifier for drive channel
               UINT8_T     type        Identifier for which data to get
               API_CHAN_CONFIG_STRUCT_T *  config_data
                                       New channel configuration data

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_set_channel_config(UINT8_T port, UINT8_T chan, UINT8_T type,
                                               API_CHAN_CONFIG_STRUCT_T *  config_data)
{
   ERRCODE_T ecode = E_SUCCESS;
   ERRCODE_T stored_ecode = E_SUCCESS;
   APHEADER_CONFIG_STRUCT_T config_info;
   API_CHAN_CONFIG_STRUCT_T active_config[API_NUM_CHAN];
   API_CHAN_CONFIG_STRUCT_T last_config;
   UINT8_T i;
   UINT8_T ci_index = 0;
   UINT8_T tkchan = 0;
   UINT8_T tktrig = 0;
   UINT32_T in_param;
   UINT32_T out_param;
   UINT8_T tkmode;
   UINT32_T width;
   UINT16_T delay;
   UINT32_T offtime;
   UINT16_T pulse_cnt;
   FLOAT32_T current;
   UINT8_T rising;
   UINT32_T crc_len;
   UINT16_T crc;

   /* Validate channel number */
   if ((chan != API_CHAN_1) && (chan != API_CHAN_2) )
   {
      ecode = API_INVALID_CHAN_ERR;
   }
   /* Validate the type information */
   else if ((type & (API_CHAN_CONFIG_DEFAULT | API_CHAN_CONFIG_ACTIVE)) == 0)
   {
      ecode = API_INVALID_CONFIG_TYPE_ERR;
   }
   /* Set default channel configuration data */
   else if ((type & API_CHAN_CONFIG_DEFAULT) != 0)
   {
      /* Get the data for all channels */
      for (i = 0; i < API_NUM_CHAN; i++)
      {
         if (ecode = api_get_channel_config(port, API_CHAN_1 + i, API_CHAN_CONFIG_DEFAULT, &active_config[i]))
         {
            break;
         }
      }

      /* Check for errors above */
      if (ecode == E_SUCCESS)
      {
         /* Save the last good configuration for the selected channel */
         memcpy(&last_config,&active_config[chan - API_CHAN_1],sizeof(API_CHAN_CONFIG_STRUCT_T));

         /* Update the configuration for the selected channel */
         memcpy(&active_config[chan - API_CHAN_1],config_data,sizeof(API_CHAN_CONFIG_STRUCT_T));

         /* Check for conflicts between the new data and the active configuration */
         for (i = 0; i < API_NUM_CHAN; i++)
         {
            /* No conflicts if no trigger is defined */
            if ((active_config[i].trigger == API_TRIG_NONE) || (config_data->trigger == API_TRIG_NONE))
            {
            }
            /* Check for conflicts with channels in pulse mode */
            else if ((active_config[i].mode == API_MODE_PULSED) || (active_config[i].mode == API_MODE_TIMING_BYPASS)
				|| (active_config[i].mode == API_MODE_REPEAT) || (active_config[i].mode == API_MODE_INTERNAL_TRIGGER))
            {
               /* The trigger and edge information for the specified channel is used by all pulsed channels */
               if ((config_data->mode == API_MODE_PULSED) || (config_data->mode == API_MODE_TIMING_BYPASS)
				   || (config_data->mode == API_MODE_REPEAT) || (config_data->mode == API_MODE_INTERNAL_TRIGGER))
               {
#if 1
                  active_config[chan - API_CHAN_1].trigger = config_data->trigger;
                  active_config[chan - API_CHAN_1].rising = config_data->rising;
#else
                  /* Allow channel 4 to be configured separately from the other channels */
                  if ((i == (API_CHAN_4 - API_CHAN_1)) || (chan == API_CHAN_4))
                  {
                     if (chan == API_CHAN_4)
                     {
                        active_config[API_CHAN_4 - API_CHAN_1].trigger = config_data->trigger;
                        active_config[API_CHAN_4 - API_CHAN_1].rising = config_data->rising;
                     }
                  }
                  else
                  {
                     active_config[i].trigger = config_data->trigger;
                     active_config[i].rising = config_data->rising;
                  }
#endif
               }
            }
            /* Check for conflicts with channels in continuous mode */
            else
            {
               /* Check for a trigger and gate conflict */
               if (((config_data->mode == API_MODE_PULSED) || (config_data->mode == API_MODE_TIMING_BYPASS)) &&
                  (config_data->trigger == active_config[i].trigger))
               {
                  ecode = API_TRIG_GATE_CONFLICT_ERR;
                  break;
               }
               /* The gate polarity for the specified channel is used for all continuous channels on the same gate */
               else if (config_data->trigger == active_config[i].trigger)
               {
                  active_config[i].rising = config_data->rising;
               }
            }
         }
      }
      
      /* Check for errors above */
      if (ecode != E_SUCCESS)
      {
      }
      /* Read the existing data from EEPROM */
      else if (ecode = tkcmdset_read_eemem_block(port,
                                            APHEADER_CONFIG_DATA_ADDRESS,
                                            (UINT8_T *) &config_info,
                                            sizeof(config_info)))
      {
      }
      /* Validate structure data */
      else if (APHEADER_CONFIG_INFO_VALID_M(&config_info))
      {
         for (i = 0; i < API_NUM_CHAN; i++)
         {
            /* Translate the operating mode */
            switch (active_config[i].mode)
            {
            case API_MODE_PULSED:            config_info.defaults[i].mode = TKPULSE_PULSE_MODE;            break;
            case API_MODE_REPEAT:            config_info.defaults[i].mode = TKPULSE_REPEAT_MODE;           break;
            case API_MODE_TIMING_BYPASS:     config_info.defaults[i].mode = TKPULSE_TIMING_BYPASS_MODE;    break;
            case API_MODE_INTERNAL_TRIGGER:  config_info.defaults[i].mode = TKPULSE_INTERNAL_TRIG_MODE;    break;
            }

            /* Translate the trigger info */
            switch (active_config[i].trigger)
            {
            case API_TRIG_1:
               config_info.defaults[i].trigger = TKPULSE_TRIG1;  
               break;
            case API_TRIG_2:
               config_info.defaults[i].trigger = TKPULSE_TRIG2;
               break;
            default:
               config_info.defaults[i].trigger = 0;
               break;
            }

            /* Build the rest of the target configuration information structure */
            config_info.defaults[i].trigger_edge = active_config[i].rising;
            config_info.defaults[i].current      = SWAP_FLOAT32_M(active_config[i].current);
            config_info.defaults[i].width        = SWAP_UINT32_M(active_config[i].width);
            config_info.defaults[i].delay        = SWAP_UINT16_M(active_config[i].delay);
            config_info.defaults[i].offtime      = SWAP_UINT32_M(active_config[i].offtime);
            config_info.defaults[i].pulse_cnt    = SWAP_UINT16_M(active_config[i].repeat_cnt);
         }

         /* Determine the length of bytes for the structure CRC value */
         /* Include all bytes in the structure except the CRC itself  */
         crc_len = sizeof(config_info) - sizeof(config_info.struct_crc);

         /* Calculate the CRC-16 value for the structure */
         TKCRC_CALC16_M((UINT8_T *) &config_info + sizeof(config_info.struct_crc),crc_len,&crc);

         /* Update the header information */
         config_info.struct_crc = SWAP_UINT16_M(crc);

         if (ecode = tkcmdset_write_eemem_block(port,
                                                APHEADER_CONFIG_DATA_ADDRESS,
                                                (UINT8_T *) &config_info,
                                                sizeof(config_info)))
         {
         }
      }
      /* Invalid structure */
      else
      {
         ecode = API_INVALID_CONFIG_CRC_ERR;
      }
   }

   /* Check for errors above */
   if (ecode != E_SUCCESS)
   {
   }
   /* Set active channel configuration data */
   else if ((type & API_CHAN_CONFIG_ACTIVE) != 0)
   {
      /* Get the data for all channels */
      for (i = 0; i < API_NUM_CHAN; i++)
      {
         if (ecode = api_get_channel_config(port, API_CHAN_1 + i, API_CHAN_CONFIG_ACTIVE, &active_config[i]))
         {
            break;
         }
      }

      /* Check for errors above */
      if (ecode == E_SUCCESS)
      {
         /* Save the last good configuration for the selected channel */
         memcpy(&last_config,&active_config[chan - API_CHAN_1],sizeof(API_CHAN_CONFIG_STRUCT_T));

         /* Update the configuration for the selected channel */
         memcpy(&active_config[chan - API_CHAN_1],config_data,sizeof(API_CHAN_CONFIG_STRUCT_T));

         /* Check for conflicts between the new data and the active configuration */
         for (i = 0; i < API_NUM_CHAN; i++)
         {
            /* No conflicts if no trigger is defined */
            if ((active_config[i].trigger == API_TRIG_NONE) || (config_data->trigger == API_TRIG_NONE))
            {
            }
            /* Check for conflicts with channels in pulse mode */
            else if ((active_config[i].mode == API_MODE_PULSED) || (active_config[i].mode == API_MODE_TIMING_BYPASS)
                  || (active_config[i].mode == API_MODE_REPEAT))
            {
               /* The trigger and edge information for the specified channel is used by all pulsed channels */
               if ((config_data->mode == API_MODE_PULSED) || (config_data->mode == API_MODE_TIMING_BYPASS)
                 ||(config_data->mode == API_MODE_REPEAT))
               {
#if 1
                  active_config[chan - API_CHAN_1].trigger = config_data->trigger;
                  active_config[chan - API_CHAN_1].rising = config_data->rising;
#else
                  /* Allow channel 4 to be configured separately from the other channels */
                  if ((i == (API_CHAN_4 - API_CHAN_1)) || (chan == API_CHAN_4))
                  {
                     if (chan == API_CHAN_4)
                     {
                        active_config[API_CHAN_4 - API_CHAN_1].trigger = config_data->trigger;
                        active_config[API_CHAN_4 - API_CHAN_1].rising = config_data->rising;
                     }
                  }
                  else
                  {
                     active_config[i].trigger = config_data->trigger;
                     active_config[i].rising = config_data->rising;
                  }
#endif

               }
            }
            /* Check for conflicts with channels in continuous mode */
            else
            {
               /* Check for a trigger and gate conflict */
               if (((config_data->mode == API_MODE_PULSED) || (config_data->mode == API_MODE_TIMING_BYPASS)) &&
                  (config_data->trigger == active_config[i].trigger))
               {
                  ecode = API_TRIG_GATE_CONFLICT_ERR;
                  break;
               }
               /* The gate polarity for the specified channel is used for all continuous channels on the same gate */
               else if (config_data->trigger == active_config[i].trigger)
               {
                  active_config[i].rising = config_data->rising;
               }
            }
         }
      }


      /* Check for errors above */
      if (ecode != E_SUCCESS)
      {
      }
      else
      {
         /* Shutdown operation by disabling all trigger sources */
         for (i = 0; i < PULSARAPI_GET_NUM_TRIG_M(); i++)
         {
            /* Disable each trigger */
            if (ecode = tkcmdset_set_trigger_map(port,(TKPULSE_TRIG1 << i),0,FALSE))
            {
               break;
            }
         }

         /* Check for errors above */
         if (ecode != E_SUCCESS)
         {
         }
         /* Disable any active internal triggers */
         else if (ecode = tkcmdset_special(port,SPECCMD_SET_INT_TRIG_CMD,0,&out_param))
         {
         }
         /* Setup the Pulsar based on the new configuration */
         else
         {
            /* Setup each channel in the new configuration  */
            for (i = 0; i < API_NUM_CHAN; i++)
            {
               /* Translate channel identifier */
               switch (API_CHAN_1 + i)
               {
               case API_CHAN_1:   tkchan = TKPULSE_CHAN1;   break;
               case API_CHAN_2:   tkchan = TKPULSE_CHAN2;   break;
               }
   
               /* Translate the trigger info */
               switch (active_config[i].trigger)
               {
               case API_TRIG_1:   tktrig = TKPULSE_TRIG1;   break;
               case API_TRIG_2:   tktrig = TKPULSE_TRIG2;   break;
               default:           tktrig = 0;               break;
               }
   
               /* Translate the mode information */
               switch (active_config[i].mode)
               {
               case API_MODE_PULSED:            tkmode = TKPULSE_PULSE_MODE;           break;        
               case API_MODE_REPEAT:            tkmode = TKPULSE_REPEAT_MODE;          break;
               case API_MODE_TIMING_BYPASS:     tkmode = TKPULSE_TIMING_BYPASS_MODE;   break;
               case API_MODE_INTERNAL_TRIGGER:  tkmode = TKPULSE_INTERNAL_TRIG_MODE;   break;
               }
   
               /* Get data from active structure */
               width = active_config[i].width;
               delay = active_config[i].delay;
               offtime = active_config[i].offtime;
               pulse_cnt = active_config[i].repeat_cnt;
               current = active_config[i].current;
               rising = active_config[i].rising;
   
               /* Check for internal trigger mode operations */
               if (tkmode == TKPULSE_INTERNAL_TRIG_MODE)
               {
                  /* Initialize channel to default values (no delay in internal trigger mode) */
                  if (ecode = tkcmdset_set_pulse(port,tkchan,width,0,current))
                  {
                  }
                  /* Configure for internal triggering */
                  else
                  {
                     in_param = (tkchan << 8) | TKPULSE_INTERNAL_TRIG_RATE;
                     ecode = tkcmdset_special(port,SPECCMD_SET_INT_TRIG_CMD,in_param,&out_param);
                  }
               }
               /* Check for pulse mode operations */
               else if (tkmode & TKPULSE_PULSE_MODE)
               {
                  /* Initialize channel to default values */
                  if (ecode = tkcmdset_set_pulse(port,tkchan,width,delay,current))
                  {
                  }
                  /* Setup default trigger mapping */
                  else if (ecode = tkcmdset_set_trigger_map(port,tktrig,tkchan,rising))
                  {
                  }
                  /* Is timing bypass enabled */
                  else if (tkmode == TKPULSE_TIMING_BYPASS_MODE)
                  {
                     in_param = (tkchan << 8) | TRUE;
                     ecode = tkcmdset_special(port,SPECCMD_SET_TIMING_BYPASS_CMD,in_param,&out_param);
                  }
                  /* Is timing bypass enabled */
                  else if (tkmode == TKPULSE_REPEAT_MODE)
                  {
                     ecode = tkcmdset_set_repeat(port,tkchan,active_config[i].offtime, active_config[i].repeat_cnt);
                  }
               }
         
               /* Exit on error */
               if (ecode)
               {
                  /* If a previous error was detected return the previous error code */
                  if (stored_ecode)
                  {
                     break;
                  }
                  /* If the error was caused by the selected channel then revert to the old data */
                  else if (i == (chan - API_CHAN_1))
                  {
                     /* Save this error for reporting */
                     stored_ecode = ecode;

                     TKTIME_DELAY_MS_M(TKTIME_TWO_SEC);

                     /* Restore the original configuration data */
                     memcpy(&active_config[i],&last_config,sizeof(API_CHAN_CONFIG_STRUCT_T));

                     /* Decrement the loop index to force this channel to be configured back to the original settings */
                     i--;
                  }
                  /* Exit on all other errors */
                  else
                  {
                     break;
                  }         
               }
            }
         }
      }
   }

   if (stored_ecode)
   {
      ecode = stored_ecode;
   }

   return(ecode);
}


/****************************************************************************
   api_trigger

   About:   Generates a software trigger on the selected trigger channel
   
   Inputs:  UINT8_T   port       Identifier for device
            UINT8_T   trig       Trigger to activate

   Outputs: None
   
   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_trigger(UINT8_T port, UINT8_T trig)
{
   switch(trig)
   {
   case API_TRIG_1:   return tkcmdset_trigger(port,TKPULSE_TRIG1);
   case API_TRIG_2:   return tkcmdset_trigger(port,TKPULSE_TRIG2);
   default:           return API_INVALID_TRIG_ERR;
   }
}

/*******************************************************************************
   api_calc_led_temp

   About:   Calculates the expected LED junction temperature based on the
            information stored in the lighthead data structure and the width
            and current information passed.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute LED temperature
            UINT32_T    width       Pulse width in microseconds
            FLOAT32_T   current     Pulse current in amps
   
   Outputs: FLOAT32_T  *temp        Location to store calculated temperature

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_calc_led_temp(UINT8_T port, UINT8_T ch, 
                                       UINT32_T width, FLOAT32_T current, FLOAT32_T *temp)
{
   switch (ch)
   {
   case API_CHAN_1:   return tkcmdset_calc_led_temp(port,TKPULSE_CHAN1,width,current,temp);
   case API_CHAN_2:   return tkcmdset_calc_led_temp(port,TKPULSE_CHAN2,width,current,temp);
   default:           return API_INVALID_CHAN_ERR;
   }

}

/*******************************************************************************
   api_calc_max_width

   About:   Calculates the maximum pulse width for the selected channel based 
            on the information stored in the lighthead data structure and the 
            current information passed.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute LED temperature
            FLOAT32_T   current     Pulse current in amps
   
   Outputs: UINT32_T   *width       Maximum pulse width in microseconds

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_calc_max_width(UINT8_T port, UINT8_T ch, 
                                        FLOAT32_T current, UINT32_T * width)
{
   switch (ch)
   {
   case API_CHAN_1:   return tkcmdset_calc_max_width(port,TKPULSE_CHAN1,current,width);
   case API_CHAN_2:   return tkcmdset_calc_max_width(port,TKPULSE_CHAN2,current,width);
   default:           return API_INVALID_CHAN_ERR;
   }
}

/*******************************************************************************
   api_calc_max_current

   About:   Calculates the maximum pulse current for the selected channel based 
            on the information stored in the lighthead data structure and the 
            width information passed.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute LED temperature
            UINT32_T    width       Pulse width in microseconds
   
   Outputs: FLOAT32_T  *current     Maximum pulse current in amps

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_calc_max_current(UINT8_T port, UINT8_T ch, 
                                          UINT32_T width, FLOAT32_T *current)
{
   switch (ch)
   {
   case API_CHAN_1:   return tkcmdset_calc_max_current(port,TKPULSE_CHAN1,width,current);
   case API_CHAN_2:   return tkcmdset_calc_max_current(port,TKPULSE_CHAN2,width,current);
   default:           return API_INVALID_CHAN_ERR;
   }
}

/*******************************************************************************
   api_calc_supply_voltage

   About:   Calculates the required supply voltage for a given width and current.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute required supply voltage
            UINT32_T    width       Pulse width in microseconds
            FLOAT32_T   current     Pulse current in amps
   
   Outputs: FLOAT32_T  *voltage     Location to store calculated voltage

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_calc_supply_voltage(UINT8_T port, UINT8_T ch, 
                                                    UINT32_T width, FLOAT32_T current, FLOAT32_T *voltage)
{
   switch (ch)
   {
   case API_CHAN_1:   return tkcmdset_calc_supply_voltage(port,TKPULSE_CHAN1,width,current,voltage);
   case API_CHAN_2:   return tkcmdset_calc_supply_voltage(port,TKPULSE_CHAN2,width,current,voltage);
   default:           return API_INVALID_CHAN_ERR;
   }
}

/*******************************************************************************
   api_calc_max_freq

   About:   Calculates the maximum frequency allowed for a given width and current.
            This function computes maximum frequency based on the maximum power of
            the power supply and also from the LED cooling equations.  The lower
            value is returned.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute maximum frequency
            UINT32_T    width       Pulse width in microseconds
            FLOAT32_T   current     Pulse current in amps
   
   Outputs: UINT16_T   *freq        Location to store calculated frequency

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_calc_max_freq(UINT8_T port, UINT8_T ch, 
                                       UINT32_T width, FLOAT32_T current, UINT16_T *freq)
{
   switch (ch)
   {
   case API_CHAN_1:   return tkcmdset_calc_max_freq(port,TKPULSE_CHAN1,width,current,freq);
   case API_CHAN_2:   return tkcmdset_calc_max_freq(port,TKPULSE_CHAN2,width,current,freq);
   default:           return API_INVALID_CHAN_ERR;
   }
}

/*******************************************************************************
   api_measure_drive_current

   About:   Measures the drive current of the selected drive channel.  This 
            function can be used in either pulse or continuous modes.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to measure pulse current
   
   Outputs: FLOAT32_T  *current     Location to store measured pulse current

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_measure_drive_current(UINT8_T port, UINT8_T ch, FLOAT32_T *current)
{
   switch (ch)
   {
   case API_CHAN_1:   return tkcmdset_special(port,SPECCMD_MEASURE_DRIVE_CURRENT_CMD,TKPULSE_CHAN1,(UINT32_T *) current);
   case API_CHAN_2:   return tkcmdset_special(port,SPECCMD_MEASURE_DRIVE_CURRENT_CMD,TKPULSE_CHAN2,(UINT32_T *) current);
   default:           return API_INVALID_CHAN_ERR;
   }
}

/*******************************************************************************
   api_measure_voltage

   About:   Measures the voltage of one of the signals monitored by the Pulsar.
   
   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     id          Identifier for desired voltage to measure
   
   Outputs: FLOAT32_T  *voltage     Location to store measured voltage

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_measure_voltage(UINT8_T port, UINT8_T id, FLOAT32_T *voltage)
{
   return (tkcmdset_get_volts(port,id,voltage));
}

/*******************************************************************************
   api_get_user_data

   About:   Gathers various information about the operating state of the Pulsar.

   Inputs:  UINT8_T     port        Identifier for device
   
   Outputs: UINT16_T   *rotary      Value on rotary switches
            UINT8_T    *dip         Value on DIP switches
            UINT8_T    *trigger     State of trigger inputs
            UINT8_T    *connect     Communication connection status
            UINT8_T    *supply      Power supply status
            UINT8_T    *expansion   Expansion status

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise

   Notes:   A NULL can be passed for any data values not needed
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_user_data(UINT8_T port,UINT16_T *rotary,UINT8_T *dip,UINT8_T *trigger,
                                       UINT8_T *connect,UINT8_T *supply,UINT8_T *expansion)
{
   ERRCODE_T ecode;
   UINT32_T  user_data;

   /* Get the user data from the Pulsar */
   if (ecode = tkcmdset_special(port,SPECCMD_GET_USER_DATA_CMD,0,&user_data))
   {
   }
   /* Unpack the information into the returned parameters */
   else
   {
      if (rotary)    *rotary    = (UINT16_T) ((user_data & SPECCMD_ROTARY_SWITCH_MASK) >> SPECCMD_ROTARY_SWITCH_SHIFT);
      if (dip)       *dip       = (UINT8_T)  ((user_data & SPECCMD_DIP_SWITCH_MASK   ) >> SPECCMD_DIP_SWITCH_SHIFT);
      if (trigger)   *trigger   = (UINT8_T)  ((user_data & SPECCMD_TRIGGER_MASK      ) >> SPECCMD_TRIGGER_SHIFT);
      if (connect)   *connect   = (UINT8_T)  ((user_data & SPECCMD_CONNECTED_MASK    ) >> SPECCMD_CONNECTED_SHIFT);
      if (supply)    *supply    = (UINT8_T)  ((user_data & SPECCMD_SUPPLY_MASK       ) >> SPECCMD_SUPPLY_SHIFT);
      if (expansion) *expansion = (UINT8_T)  ((user_data & SPECCMD_EXPANSION_MASK    ) >> SPECCMD_EXPANSION_SHIFT);
   }

   return(ecode);
}


/*******************************************************************************
   api_get_light_data

   About:   Gathers information regarding the lighthead type.

   Inputs:  UINT8_T     port        Identifier for device
   
   Outputs: UINT8_T    *sig_model   1 - Signatech I, 2 - Signatech II, 0 - Unknown
            UINT8_T    *sig1_id     Set for Signatech I lightheads, zero otherwise
            char       *sig2_pn     Set to part number string for Signatech II, NULL otherwise

   Returns: ERRCODE_T ecode         Status of command
                                       Zero if successful,
                                       Error code otherwise

********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_light_data(UINT8_T port, UINT8_T *sig_model, UINT8_T *sig1_id, char *sig2_pn, char *sig2_sn)
{
   TKCMDSET_LIGHTHEAD_STRUCT_T lh_info;
   UINT32_T lh_sn = 0;
   char temp[50];
   ERRCODE_T ecode;
   *sig_model = 0;
   *sig1_id = 0;
   *sig2_pn = NULL;
   *sig2_sn = NULL;

#if 0
   if (LoaderActive == FALSE)
   {
   }
   else 
#endif
   /* Read the lighthead serial number */
   if (ecode = tkcmdset_special(port,SPECCMD_GET_LH_SERIALNUM_CMD,0,&lh_sn))
   {
   }
   /* Read the lighthead configuration information */
   else if (ecode = tkcmdset_get_lighthead_data(port, &lh_info))
   {
   }
   /* Load the data if it is valid */
   else
   {
      sprintf(sig2_pn, "%s", lh_info.part_number);
   }

   /* Display the serial number */
   if (lh_sn)
   {
      sprintf(sig2_sn,"%d",lh_sn);
   }

   return(ecode);
#if 0
   APHEADER_LIGHTHEAD_STRUCT_T lh_info;
   ERRCODE_T ecode;
   UINT32_T id_val;

   *sig_model = 0;
   *sig1_id = 0;
   *sig2_pn = NULL;

   /* Check for Signatech I lighthead */
   if ((ecode = tkcmdset_special(port,SPECCMD_GET_SIG1_ID_CMD,0,&id_val)) == TKLIGHT_NOT_SIG1_ERR)
   {
      *sig_model = 2;

      /* Read the lighthead configuration information */
      if (ecode = tkcmdset_read_eemem_block(port,
                                            APHEADER_LIGHTHEAD_DATA_ADDRESS,
                                            (UINT8_T *) &lh_info,
                                            sizeof(lh_info)))
      {
         *sig_model = 0;
      }
      /* Load the Signatech II part number it is valid */
      else if (APHEADER_LIGHTHEAD_INFO_VALID_M(&lh_info))
      {
         strncpy(sig2_pn,(char *) lh_info.part_number,sizeof(lh_info.part_number));
      }
      /* Bad CRC */
      else
      {
         ecode = API_INVALID_LIGHTHEAD_CRC_ERR;
      }
   }
   /* Store the Signatech I ID value */
   else if (ecode == NO_ERR)
   {
      *sig_model = 1;
      *sig1_id = LO_BYTE(LO_WORD(id_val));
   }
#endif
   return(ecode);
}

/*******************************************************************************
   api_set_stored_data

   About:   Saves a block of Ai defined data to EEPROM.
   
   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T    *data        Pointer to data block to be written
            UINT8_T     len         Length of data block to be written
   
   Outputs: None

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_set_stored_data(UINT8_T port, UINT8_T *data, UINT8_T len)
{
   ERRCODE_T ecode;
   APHEADER_AI_STORAGE_STRUCT_T ai_info;
   UINT32_T crc_len;
   UINT16_T crc;

   /* Make sure the length is valid */
   if (len > sizeof(ai_info.data))
   {
      ecode = API_INVALID_STORAGE_LEN_ERR;
   }
   /* Read the current data from the Pulsar */
   else if (ecode = tkcmdset_read_eemem_block(port,
                                         APHEADER_AI_STORAGE_DATA_ADDRESS,
                                         (UINT8_T *) &ai_info,
                                         sizeof(ai_info)))
   {
   }
   /* Add the new data to the data block and save */
   else
   {
      /* Copy the new data into the data block, preserving existing data beyond len */
      memcpy(ai_info.data,data,len);

      /* Update the header information */
      ai_info.struct_type = SWAP_UINT16_M(APHEADER_AI_STORAGE_TYPE);
      ai_info.struct_rev = SWAP_UINT16_M(APHEADER_AI_STORAGE_STRUCT_REV);

      /* Determine the length of bytes for the structure CRC value */
      /* Include all bytes in the structure except the CRC itself  */
      crc_len = sizeof(ai_info) - sizeof(ai_info.struct_crc);

      /* Calculate the CRC-16 value for the structure */
      TKCRC_CALC16_M((UINT8_T *) &ai_info + sizeof(ai_info.struct_crc),crc_len,&crc);

      /* Update the header information */
      ai_info.struct_crc = SWAP_UINT16_M(crc);
      
      /* Write the data back to EEPROM */
      ecode = tkcmdset_write_eemem_block(port,
                                         APHEADER_AI_STORAGE_DATA_ADDRESS,
                                         (UINT8_T *) &ai_info,
                                         sizeof(ai_info));
   }

   return(ecode);
}

/*******************************************************************************
   api_get_stored_data

   About:   Reads a block of Ai defined data from EEPROM.
   
   Inputs:  UINT8_T     port        Identifier for device            
            UINT8_T     len         Length of data block to read
   
   Outputs: UINT8_T    *data        Pointer to data block to be written

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_stored_data(UINT8_T port, UINT8_T *data, UINT8_T len)
{
   ERRCODE_T ecode;
   APHEADER_AI_STORAGE_STRUCT_T ai_info;

   /* Make sure the length is valid */
   if (len > sizeof(ai_info.data))
   {
      ecode = API_INVALID_STORAGE_LEN_ERR;
   }
   /* Read the current data from the Pulsar */
   else if (ecode = tkcmdset_read_eemem_block(port,
                                         APHEADER_AI_STORAGE_DATA_ADDRESS,
                                         (UINT8_T *) &ai_info,
                                         sizeof(ai_info)))
   {
   }
   /* Validate the structure data */
   else if (APHEADER_AI_STORAGE_INFO_VALID_M(&ai_info))
   {
      /* Copy the data block into the returned buffer */
      memcpy(data,ai_info.data,len);
   }
   /* Invalid structure */
   else
   {
      ecode = API_INVALID_STORAGE_CRC_ERR;
   }

   return(ecode);
}



/****************************************************************************
   api_shutdown

   About:      Shuts down the connection to a specific Pulsar

   Inputs:     UINT8_T     port        Communication port to use

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_shutdown(UINT8_T port)
{
   return tkcmdset_shutdown(port);
}

/****************************************************************************
   api_shutdown

   About:      Shuts down the connection to a specific Pulsar

   Inputs:     UINT8_T     port        Communication port to use

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_set_configuration(UINT8_T port, UINT8_T* slew_rate, UINT8_T* diff_trigger, UINT8_T limit48v, UINT8_T disable_prot)
{
	APHEADER_CONFIG_STRUCT_T config_info;
	APHEADER_MANUFACTURE_STRUCT_T mfg_data;
	ERRCODE_T ecode = NO_ERR;
	UINT32_T crc_len;
	UINT16_T crc;

	/* Read the existing data from EEPROM */
	if (ecode = tkcmdset_read_eemem_block(port,
		                                  APHEADER_CONFIG_DATA_ADDRESS,
                                          (UINT8_T *) &config_info,
                                          sizeof(config_info)))
    {
    }
    /* Validate structure data */
    else if (APHEADER_CONFIG_INFO_VALID_M(&config_info))
	{
		config_info.defaults[0].slew_rate = slew_rate[0];
		config_info.defaults[1].slew_rate = slew_rate[1];
		diff_trigger[0] = !(diff_trigger[0] == 0);
		diff_trigger[1] = !(diff_trigger[1] == 0);
		config_info.diff_trig = diff_trigger[0] | (diff_trigger[1]<<1);
		/* Determine the length of bytes for the structure CRC value */
		/* Include all bytes in the structure except the CRC itself  */
		crc_len = sizeof(config_info) - sizeof(config_info.struct_crc);

		/* Calculate the CRC-16 value for the structure */
		TKCRC_CALC16_M((UINT8_T *) &config_info + sizeof(config_info.struct_crc),crc_len,&crc);

		/* Update the header information */
		config_info.struct_crc = SWAP_UINT16_M(crc);

		if (ecode = tkcmdset_write_eemem_block(port,
											APHEADER_CONFIG_DATA_ADDRESS,
											(UINT8_T *) &config_info,
											sizeof(config_info)))
		{
		}

		/* Get the board mfg data */
		else if (ecode = tkcmdset_read_eemem_block(port,APHEADER_MANUFACTURE_DATA_ADDRESS,(UINT8_T *) &mfg_data,sizeof(mfg_data)))
		{
		}
		else if (APHEADER_MANUFACTURE_INFO_VALID_M(&mfg_data)) /* Validate board calibration structure */
			{
				if(limit48v)
				{
					mfg_data.hw_config |= APHEADER_CONFIG_48V_LIMIT; 
				}
				else
				{
					mfg_data.hw_config &= APHEADER_CONFIG_48V_LIMIT; 
				}
				/* Determine the length of bytes for the structure CRC value */
				/* Include all bytes in the structure except the CRC itself  */
				crc_len = sizeof(mfg_data) - sizeof(mfg_data.struct_crc);

				/* Calculate the CRC-16 value for the structure */
				TKCRC_CALC16_M((UINT8_T *) &mfg_data + sizeof(mfg_data.struct_crc),crc_len,&crc);

				/* Update the header information */
				mfg_data.struct_crc = SWAP_UINT16_M(crc);

				if (ecode = tkcmdset_write_eemem_block(port,
													APHEADER_MANUFACTURE_DATA_ADDRESS,
													(UINT8_T *) &mfg_data,
													sizeof(mfg_data)))
				{
				}
			}
		}
	return(ecode);
}

/****************************************************************************
   api_shutdown

   About:      Shuts down the connection to a specific Pulsar

   Inputs:     UINT8_T     port        Communication port to use

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_configuration(UINT8_T port, UINT8_T * pslew_rate, UINT8_T * pdiff_trigger, UINT8_T* limit48v, UINT8_T* disable_prot)
{
	APHEADER_CONFIG_STRUCT_T config_info;
	APHEADER_MANUFACTURE_STRUCT_T mfg_data;
	ERRCODE_T ecode = NO_ERR;
	*limit48v = false;
	*disable_prot = false;
	UINT8_T *slew_rate = pslew_rate;
	BOOLEAN_T *diff_trigger = pdiff_trigger;

	/* Read the existing data from EEPROM */
	if (ecode = tkcmdset_read_eemem_block(port,
		                                  APHEADER_CONFIG_DATA_ADDRESS,
                                          (UINT8_T *) &config_info,
                                          sizeof(config_info)))
    {
    }
    /* Validate structure data */
    else if (APHEADER_CONFIG_INFO_VALID_M(&config_info))
	{
	   slew_rate[0] = config_info.defaults[0].slew_rate;
	   slew_rate[1] = config_info.defaults[1].slew_rate ;
	   diff_trigger[0] = config_info.diff_trig & 0x01;
	   diff_trigger[1] = (config_info.diff_trig>>1) & 0x01;
	}
	/* Get the board mfg data */
	if (ecode = tkcmdset_read_eemem_block(port,APHEADER_MANUFACTURE_DATA_ADDRESS,(UINT8_T *) &mfg_data,sizeof(mfg_data)))
	{
	}
	else
	{
		/* Validate board calibration structure */
		if (APHEADER_MANUFACTURE_INFO_VALID_M(&mfg_data))
		{
			if(mfg_data.hw_config & APHEADER_CONFIG_48V_LIMIT)
			{
				*limit48v = true;
			}
		}
	}
	return(ecode);
}

/****************************************************************************
   api_reset_default_tcp

   About:      Resets ethernet settings to default IP settings and MAC address.

   Inputs:     UINT8_T     port        Communication port to use

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_reset_default_tcp(UINT8_T port)
{
	APHEADER_MANUFACTURE_STRUCT_T mfg_data;
	ERRCODE_T ecode = NO_ERR;
	/* Get the board mfg data */
	if (ecode = tkcmdset_read_eemem_block(port,APHEADER_MANUFACTURE_DATA_ADDRESS,(UINT8_T *) &mfg_data,sizeof(mfg_data)))
	{
	}
	else
	{
		/* Validate board calibration structure */
		if (APHEADER_MANUFACTURE_INFO_VALID_M(&mfg_data))
		{
			tkcmdset_set_mac(port, mfg_data.default_mac);
			tkcmdset_set_ip(port, mfg_data.default_ip, 0xFFFFFF00, mfg_data.default_ip);
		}
	}
	return(ecode);
}

/*===============================================================
   AddLongs_SafeAray - a function to add all elements of an one-dimensional
   array of longs
   return codes: 0 - Success
                 >0 - Failure
   =================================================================*/ 
long __declspec (dllexport) __stdcall AddLongs_SafeArray(
      long *psaArray, // the array to use
      long *plSum) // returns the sum of all elements of the array
{
      long lElements; // number of elements in the array
      long iCount;
      HRESULT lResult; // return code for OLE functions
      long *pArrayElements; // pointer to the elements of the array

      // initializing the output
      *plSum=0;
	  *psaArray = 0;
	
/*
      // checking if it is an one-dimensional array
      if ( (*psaArray)->cDims != 1 ) return(1);

      // checking if it is an array of longs
      if ( (*psaArray)->cbElements != 4 ) return(2);

      // how many elements are there in the array
      lElements=(*psaArray)->rgsabound[0].cElements;

      // locking the array before using its elements
      lResult=SafeArrayLock(*psaArray);
      if(lResult)return(3);

      // using the array
      pArrayElements=(long*) (*psaArray)->pvData;
      for (iCount=0; iCount < lElements; iCount++)
         *plSum = *plSum + pArrayElements[iCount];

      // releasing the array
      lResult=SafeArrayUnlock(*psaArray);
      if (lResult) return(4);
*/
      // returning
      return(0);
   }
			