/*******************************************************************************
********************************************************************************

   COPYRIGHT  2004, Advanced Illumination, Inc. 

   Contains confidential and proprietary information which may not be copied,
   disclosed or used by others except as expressly authorized in writing
   by Advanced Illumination.

   ap_header.h    Application Header Information Header File

   About:         This module contains the application header information 
                  definitions for the AICONS01 project.  

   Target CPU:    H8S/2215

   Written for:   Advanced Illumination, Inc.
                  24 Peavine Drive
                  Rochester, VT 05767
                  http://advancedillumination.com

   Contacts:      John Thrailkill
                  Phone:  (802) 767-3830
                  FAX:    (802) 767-3831
                  jthrailkill@advill.com

   Written by:    Rob Macklin
                  Microprocessor Designs, Inc.
                  65 Longmeadow Drive
                  PO Box 160
                  Shelburne, VT 05482
                  http://www.updesigns.com

   $Revision: 3 $

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
   $Log: /Advanced Illumination/Pulsar320/tar_src/H8App/ap_header.h $
 * 
 * 3     8/21/08 12:36p Jpiet
 * Added parameters for repeat mode operation
 * 
 * 2     8/15/08 11:40a Jpiet
 * 
 * 1     8/15/08 8:45a Jpiet
 * Initial check-in
 * 
 * 21    5/15/08 9:39a Rmack
 * Name change.
 * 
 * 20    5/14/08 5:12p Rmack
 * Changes to support 32-bit width parameter.
 * 
 * 19    12/30/05 3:28p Rmack
 * Added storage location for max_lv_volts.
 * 
 * 18    5/16/05 9:01a Rmack
 * Changed lighthead max current parameter to work on a string basis.
 * 
 * 17    2/09/05 3:03p Rmack
 * Added revision information for AI storage structure.
 * 
 * 14    11/10/04 11:05a Rmack
 * Changed units on thermal resistance values.
 * 
 * 12    10/07/04 3:44p Rmack
 * Another change to the configuration structure.
 * 
 * 11    10/07/04 3:15p Rmack
 * Redefined configuration data structure to include separate defaults for
 * each channel.
 * 
 * 10    10/07/04 12:23p Rmack
 * New lighthead structure definition including default current.
 * 
 * 9     10/01/04 9:57a Rmack
 * Redefined configuration structure, reserved 256 bytes total.
 * 
 * 8     9/30/04 11:06a Rmack
 * Updated lighthead data structure
 * 
 * 6     9/22/04 4:13p Rmack
 * Defined new configuration structure.
 * 
 * 4     7/01/04 10:30a Jwayg
 * Last code release before transfer of source files to new programmer.
 * 
 * 3     6/01/04 5:04p Jwayg
 * S1000 - in process version with test pulses - being geared for Jon's
 * hardware testing - 8200-000068-003 level
 * 
 * 2     5/17/04 10:56a Jwayg
 * Common Files for Initial Running Version of S1000 
 * 
 * 1     3/30/04 3:31p Rmack
 *
********************************************************************************
*******************************************************************************/
#ifndef __APHEADER_H__
#define __APHEADER_H__

/*******************************************************************************
********************************************************************************
									Definitions
********************************************************************************
*******************************************************************************/
/* Root part numbers for loader firmware */
#define APHEADER_LOADER_SOURCE_BASE_PN             "8100-000157"
#define APHEADER_LOADER_EXE_BASE_PN                "8200-000218"

#define APHEADER_APP_SOURCE_BASE_PN                "8100-000158"
#define APHEADER_APP_EXE_BASE_PN                   "8200-000219"

#define APHEADER_ID_STRING                         "Ai Strobe Controller"
#define APHEADER_APP_TYPE                          1
#define APHEADER_MANUFACTURE_TYPE                  2
#define APHEADER_CAL_TYPE                          3
#define APHEADER_CONFIG_TYPE                       4
#define APHEADER_LIGHTHEAD_TYPE                    5
#define APHEADER_AI_STORAGE_TYPE                   6

/* Structure revision information */
#define APHEADER_APP_STRUCT_REV_MAJOR              0x01
#define APHEADER_APP_STRUCT_REV_MINOR              0x00
#define APHEADER_APP_STRUCT_REV                    ((APHEADER_APP_STRUCT_REV_MAJOR << 8)          \
                                                   | APHEADER_APP_STRUCT_REV_MINOR)

#define APHEADER_MANUFACTURE_STRUCT_REV_MAJOR      0x01
#define APHEADER_MANUFACTURE_STRUCT_REV_MINOR      0x00
#define APHEADER_MANUFACTURE_STRUCT_REV            ((APHEADER_MANUFACTURE_STRUCT_REV_MAJOR << 8)  \
                                                   | APHEADER_MANUFACTURE_STRUCT_REV_MINOR)

#define APHEADER_CAL_STRUCT_REV_MAJOR              0x01
#define APHEADER_CAL_STRUCT_REV_MINOR              0x00
#define APHEADER_CAL_STRUCT_REV                    ((APHEADER_CAL_STRUCT_REV_MAJOR << 8)          \
                                                   | APHEADER_CAL_STRUCT_REV_MINOR)

#define APHEADER_AI_STORAGE_STRUCT_REV_MAJOR       0x01
#define APHEADER_AI_STORAGE_STRUCT_REV_MINOR       0x00
#define APHEADER_AI_STORAGE_STRUCT_REV             ((APHEADER_AI_STORAGE_STRUCT_REV_MAJOR << 8)   \
                                                   | APHEADER_AI_STORAGE_STRUCT_REV_MINOR)

#define APHEADER_CONFIG_STRUCT_REV_MAJOR           0x01
#define APHEADER_CONFIG_STRUCT_REV_MINOR           0x0A
#define APHEADER_CONFIG_STRUCT_REV                 ((APHEADER_CONFIG_STRUCT_REV_MAJOR << 8)       \
                                                   | APHEADER_CONFIG_STRUCT_REV_MINOR)

#define APHEADER_LIGHTHEAD_STRUCT_REV_MAJOR        0x01
#define APHEADER_LIGHTHEAD_STRUCT_REV_MINOR        0x00
#define APHEADER_LIGHTHEAD_STRUCT_REV              ((APHEADER_LIGHTHEAD_STRUCT_REV_MAJOR << 8)    \
                                                   | APHEADER_LIGHTHEAD_STRUCT_REV_MINOR)


/* Define address for manufacturing information in EEPROM */
#define APHEADER_MANUFACTURE_DATA_ADDRESS          0
#define APHEADER_CAL_DATA_ADDRESS                  0x100
#define APHEADER_CONFIG_DATA_ADDRESS               0x200
#define APHEADER_AI_STORAGE_DATA_ADDRESS           0x380
#define APHEADER_LIGHTHEAD_DATA_ADDRESS            EXTEEPROM_LH1_START_ADDR
#define APHEADER_LIGHTHEAD_DATA_ADDRESS_M(chan)    (APHEADER_LIGHTHEAD_DATA_ADDRESS+(chan*EXTEEPROM_LH1_SIZE))

/* Bit definitions for config byte in MFG header */
#define APHEADER_CONFIG_48V_LIMIT                  BIT0

/*******************************************************************************
********************************************************************************
									Data Structure Declarations
********************************************************************************
*******************************************************************************/
typedef void (*APHEADER_VOID_POINTER_T) (void);    

/* application data structure */
typedef struct
{
   UINT16_T struct_crc;
   UINT16_T struct_type;
   UINT16_T struct_rev;
   UINT8_T  fw_id[32];
   UINT8_T  pn_source[16];
   UINT8_T  pn_exe[16];
   APHEADER_VOID_POINTER_T app_init_start;
   APHEADER_VOID_POINTER_T app_start;
   APHEADER_VOID_POINTER_T app_end;
   UINT16_T app_crc;
   UINT8_T  notes[52];
}  APHEADER_APP_STRUCT_T;

/* manufacturing info data structure */
typedef struct
{
   UINT16_T struct_crc;
   UINT16_T struct_type;
   UINT16_T struct_rev;
   UINT8_T  serial_num[16];
   UINT8_T  julian_date[16];
   UINT8_T  pn_hw[16];
   UINT8_T  eco_rev[4];
   UINT16_T tests_pass;
   UINT8_T  diag_test_byte;
   UINT8_T  default_mac[6];
   UINT32_T default_ip;
   UINT8_T  hw_config;
   UINT8_T  notes[55];
} APHEADER_MANUFACTURE_STRUCT_T;

/* calibration data structure */
typedef struct
{
   UINT16_T struct_crc;
   UINT16_T struct_type;
   UINT16_T struct_rev;
   UINT8_T  cal_date[20];
   FLOAT32_T vref_desired;
   FLOAT32_T vref_actual;
   FLOAT32_T vref_offset;
   FLOAT32_T vref_counts;
   UINT8_T  notes[78];
} APHEADER_CAL_STRUCT_T;

typedef struct
{
   UINT16_T struct_crc;
   UINT16_T struct_type;
   UINT16_T struct_rev;
   UINT16_T reserved;
   UINT8_T  data[120];
} APHEADER_AI_STORAGE_STRUCT_T;

typedef struct
{
   UINT8_T   trigger;
   UINT8_T   trigger_edge;
   UINT8_T   mode;
   UINT8_T   slew_rate;
   UINT16_T  width16;  /* For reverse compatibility */
   UINT16_T  delay;
   FLOAT32_T current;
   UINT32_T  width;
   UINT32_T  offtime;
   UINT16_T  pulse_cnt;
   UINT8_T   reserved[18];
}  APHEADER_CHAN_CONFIG_STRUCT_T;              /* 40 bytes */
typedef struct
{
   UINT16_T  struct_crc;
   UINT16_T  struct_type;
   UINT16_T  struct_rev;
   FLOAT32_T hv_overhead;
   FLOAT32_T lv_overhead;
   UINT8_T   initial_lighthead_temp[4];
   FLOAT32_T max_lv_volts;     
   UINT8_T   diff_trig;
   UINT8_T   reserved[73];                     /*  96 bytes of common info */
   APHEADER_CHAN_CONFIG_STRUCT_T defaults[4];  /* 160 bytes of channel info */
}  APHEADER_CONFIG_STRUCT_T;                   /* 256 bytes total */


/* light head channel data structure */
typedef struct
{
   UINT16_T  led_r_th;                  /* 1 100 milli-degree C / bit, LED Thermal resistance */
   UINT16_T  tau;                       /* 1 uSec / bit, Thermal time constant */
   FLOAT32_T led_voltage_slope;         /* no units  , scale factor to calculate LED Vf */
   UINT16_T  led_voltage_offset;        /* 1 mV / bit, offset used to calculate LED Vf */
   UINT8_T   max_junct_temp;            /* 1 degree C / bit, Maximum junction temperature */
   UINT8_T   num_str_led;               /* number of strings in upper nibble, number of LEDs per string lower nibble */
   UINT16_T  hs_r_th;                   /* 1 100 milli-degree C / bit, Heatsink Thermal resistance */
   UINT16_T  default_current;           /* 1 mA / bit, default LED current */
   UINT16_T  max_pulse_current;         /* 1 mA / bit, maximum LED current in pulse mode */
   UINT16_T  max_cont_current;          /* 1 mA / bit, maximum LED current in continuous mode */
} APHEADER_CHANNEL_STRUCT_T;            /* 20 bytes total */

/* LED Vf = (desired LED current) * led_voltage_slope + led_voltage_offset */
 

/* light head data structure */
typedef struct
{
  UINT16_T struct_crc;
  UINT16_T struct_type;
  UINT16_T struct_rev;
  UINT8_T  active_channels;
  UINT8_T  allowed_modes;
  UINT8_T  part_number[16];
  UINT8_T  mfg_date[20];
  UINT8_T reserved[4];                  /*  48 bytes of common info */
  APHEADER_CHANNEL_STRUCT_T chan[4];    /*  80 bytes of channel info */
} APHEADER_LIGHTHEAD_STRUCT_T;          /* 128 bytes total */



/*******************************************************************************
********************************************************************************
								Externals
********************************************************************************
*******************************************************************************/
extern const APHEADER_APP_STRUCT_T apheader_app_info;
extern APHEADER_APP_STRUCT_T * const apheader_header_search_addresses[];
extern const UINT8_T apheader_num_search_addresses;

#define APHEADER_GET_SOURCE_PARTNUM_M(hdr, bufptr) \
   memcpy((INT8_T *) (bufptr),                     \
          (INT8_T *) (hdr).pn_source,              \
          sizeof((hdr).pn_source))

#define APHEADER_GET_EXE_PARTNUM_M(hdr, bufptr)    \
   memcpy((INT8_T *) (bufptr),                     \
          (INT8_T *) (hdr).pn_exe,                 \
          sizeof((hdr).pn_exe))

#define APHEADER_GET_UNICODE_PARTNUM_M(hdr, bufptr)\
{                                                  \
   UINT8_T  *hbuf = (hdr).pn_exe;                  \
   UINT16_T *ubuf = (UINT16_T *) bufptr;           \
   while (*ubuf = *hbuf++) *ubuf++ <<= 8;          \
}

#define APHEADER_APP_INFO_VALID_M(hdr)             \
   apheader_app_info_valid(hdr)
#define APHEADER_APP_CODE_VALID_M(hdr)             \
   apheader_app_code_valid(hdr)
#define APHEADER_MANUFACTURE_INFO_VALID_M(hdr)     \
   apheader_manufacture_info_valid(hdr)
#define APHEADER_CAL_INFO_VALID_M(hdr)             \
   apheader_cal_info_valid(hdr)
#define APHEADER_AI_STORAGE_INFO_VALID_M(hdr)      \
   apheader_ai_storage_info_valid(hdr)
#define APHEADER_CONFIG_INFO_VALID_M(hdr)          \
   apheader_config_info_valid(hdr)
#define APHEADER_LIGHTHEAD_INFO_VALID_M(hdr)       \
   apheader_lighthead_info_valid(hdr)



/*******************************************************************************
********************************************************************************
								Prototypes
********************************************************************************
*******************************************************************************/
#ifdef __cplusplus
extern "C" {
#endif

BOOLEAN_T apheader_app_info_valid(APHEADER_APP_STRUCT_T * hdr);
BOOLEAN_T apheader_app_code_valid(APHEADER_APP_STRUCT_T * hdr);
BOOLEAN_T apheader_manufacture_info_valid(APHEADER_MANUFACTURE_STRUCT_T * hdr);
BOOLEAN_T apheader_cal_info_valid(APHEADER_CAL_STRUCT_T * hdr);
BOOLEAN_T apheader_ai_storage_info_valid(APHEADER_AI_STORAGE_STRUCT_T * hdr);
BOOLEAN_T apheader_config_info_valid(APHEADER_CONFIG_STRUCT_T * hdr);
BOOLEAN_T apheader_lighthead_info_valid(APHEADER_LIGHTHEAD_STRUCT_T * hdr);
   
#ifdef __cplusplus
}
#endif

#endif /* __APHEADER_H__ */