/*******************************************************************************
********************************************************************************

   COPYRIGHT  2004, Advanced Illumination, Inc. 

   Contains confidential and proprietary information which may not be copied,
   disclosed or used by others except as expressly authorized in writing
   by Advanced Illumination.

   tk_time.h      External definitions for the Time Management Toolkit functions

   About:         This module contains external definitions for the Time Management
                  Toolkit functions in the AICONS01 project.

   Target:        Win32 Compatible

   Written for:   Advanced Illumination, Inc.
                  24 Peavine Drive
                  Rochester, VT 05767
                  http://advancedillumination.com

   Contacts:      John Thrailkill
                  Phone:  (802) 767-3830
                  FAX:    (802) 767-3831
                  jthrailkill@advill.com

   Written by:    Rob Macklin
                  Microprocessor Designs, Inc.
                  65 Longmeadow Drive
                  PO Box 160
                  Shelburne, VT 05482
                  http://www.updesigns.com

   $Revision: 3 $

--------------------------------------------------------------------------------
   $Log: /Advanced Illumination/Pulsar320/pc_src/Pulsar320Loader/tk_time.h $
 * 
 * 3     8/15/08 1:13p Jpiet
 * Added twenty second define
 * 
 * 2     8/24/04 8:44a Rmack
 * Updated header information.
 * 
 * 1     3/30/04 3:27p Rmack
 * 
********************************************************************************
*******************************************************************************/
#ifndef _TKTIME_H
#define _TKTIME_H

#include <mmsystem.h>

/* Definitions for common values */
#define TKTIME_TIME_PER_TICK     0.001

#define TKTIME_ONE_MSEC          (UINT32_T) (0.001/TKTIME_TIME_PER_TICK)
#define TKTIME_TEN_MSEC          (UINT32_T) (0.010/TKTIME_TIME_PER_TICK)
#define TKTIME_FIFTY_MSEC        (UINT32_T) (0.050/TKTIME_TIME_PER_TICK)
#define TKTIME_ONE_TENTH_SEC     (UINT32_T) (0.10/TKTIME_TIME_PER_TICK)
#define TKTIME_ONE_QUARTER_SEC   (UINT32_T) (0.25/TKTIME_TIME_PER_TICK)
#define TKTIME_ONE_HALF_SEC      (UINT32_T) (0.50/TKTIME_TIME_PER_TICK)
#define TKTIME_ONE_SEC           (UINT32_T) (1./TKTIME_TIME_PER_TICK)
#define TKTIME_TWO_SEC           (UINT32_T) (2./TKTIME_TIME_PER_TICK)
#define TKTIME_THREE_SEC         (UINT32_T) (3./TKTIME_TIME_PER_TICK)
#define TKTIME_FOUR_SEC          (UINT32_T) (4./TKTIME_TIME_PER_TICK)
#define TKTIME_FIVE_SEC          (UINT32_T) (5./TKTIME_TIME_PER_TICK)
#define TKTIME_TEN_SEC           (UINT32_T) (10./TKTIME_TIME_PER_TICK)
#define TKTIME_TWENTY_SEC        (UINT32_T) (20./TKTIME_TIME_PER_TICK)
#define TKTIME_SIXTY_SEC         (UINT32_T) (60./TKTIME_TIME_PER_TICK)

/* Macro interfaces for all toolkit functions */
#define TKTIME_INIT_M()                   tktime_init()
#define TKTIME_GETTIME_M()                (UINT32_T) timeGetTime()
#define TKTIME_ELAPSED_TIME_MS_M(start)   (UINT32_T) (TKTIME_GETTIME_M() - start)
#define TKTIME_DELAY_MS_M(msecs)          tktime_delay_ms(msecs)
#define TKTIME_DELAY_US_M(usecs)          tktime_delay_us(usecs)
#define TKTIME_SHUTDOWN()                 tktime_shutdown()

/* Watchdog macro for compatibility with modules shared with firmware */
#define TKTIME_PET_WATCHDOG_M()

/* Prototypes for all toolkit functions */
ERRCODE_T tktime_init(void);
ERRCODE_T tktime_delay_ms(UINT32_T ms);
ERRCODE_T tktime_delay_us(UINT32_T us);
ERRCODE_T tktime_shutdown(void);

#endif /* _TKTIME_H */