/*******************************************************************************
********************************************************************************

   COPYRIGHT  2004, Advanced Illumination, Inc. 

   Contains confidential and proprietary information which may not be copied,
   disclosed or used by others except as expressly authorized in writing
   by Advanced Illumination.

   MPDH8USB_TCP.h External definitions for the Low Level Command Interface DLL

   About:         This module contains external definitions for the Low Level Command
                  Interface DLL functions in the AICONS01 project.

   Target:        Win32 Compatible

   Written for:   Advanced Illumination, Inc.
                  24 Peavine Drive
                  Rochester, VT 05767
                  http://advancedillumination.com

   Contacts:      John Thrailkill
                  Phone:  (802) 767-3830
                  FAX:    (802) 767-3831
                  jthrailkill@advill.com

   Written by:    Rob Macklin
                  Microprocessor Designs, Inc.
                  65 Longmeadow Drive
                  PO Box 160
                  Shelburne, VT 05482
                  http://www.updesigns.com

   $Revision: 3 $

--------------------------------------------------------------------------------
   $Log: /Advanced Illumination/Pulsar320/pc_src/MPDH8USB_TCP/MPDH8USB_TCP.h $
 *  10/14/11 JST
   Fixed comments for connect() prototype
 * 2     8/20/08 9:04a Jpiet
 * Added repeat commands
 * 
 * 1     8/15/08 12:24p Jpiet
 * 
 * 18    5/15/08 2:48p Rmack
 * Fixed init prototype.
 * 
 * 17    5/15/08 2:41p Rmack
 * Changed name of init function to force faults when loaded by old
 * applications.
 * 
 * 16    5/14/08 4:42p Rmack
 * Changed to 32-bit width parameters.
 * 
 * 13    1/25/06 11:36a Rmack
 * Added manufacturing date to new lighthead structure for application.
 * 
 * 12    1/25/06 11:17a Rmack
 * Changed structure used to pass lighthead data so calling application
 * does not need to know H8 byte order.
 * 
 * 11    1/24/06 4:17p Rmack
 * Add pack pragma around ap_header.h include.
 * 
 * 10    1/24/06 4:05p Rmack
 * Added functions to get/set lighthead data structure.
 * 
 * 9     2/17/05 4:55p Rmack
 * 
 * 8     1/06/05 2:54p Rmack
 * Added get_volts command.
 * 
 * 7     10/08/04 10:39a Rmack
 * Changed interface to supply voltage commands to include channel
 * identifier.
 * 
 * 6     10/05/04 11:31a Rmack
 * Added interfaces to new LED calculation functions.
 * 
 * 5     9/24/04 9:36a Rmack
 * Removed FIFO commands
 * 
 * 4     9/13/04 10:23a Rmack
 * Added commands for direct control of pulse outputs.
 * 
 * 3     8/24/04 10:26a Rmack
 * Added new TK_PULSE specific command interfaces.
 * 
 * 2     3/30/04 4:26p Rmack
 * Updated product name information
 * 
 * 1     3/30/04 3:25p Rmack
 * 
********************************************************************************
*******************************************************************************/
#ifndef _MPDH8USB_TCP_H
#define _MPDH8USB_TCP_H

// The following ifdef block is the standard way of creating macros which make exporting 
// from a DLL simpler. All files within this DLL are compiled with the MPDH8USB_TCP_EXPORTS
// symbol defined on the command line. this symbol should not be defined on any project
// that uses this DLL. This way any other project whose source files include this file see 
// MPDH8USB_TCP_API functions as being imported from a DLL, wheras this DLL sees symbols
// defined with this macro as being exported.
#ifdef _MSC_VER
   #ifdef MPDH8USB_TCP_EXPORTS
   #define MPDH8USB_TCP_API extern "C" __declspec(dllexport)
   #else
   #define MPDH8USB_TCP_API extern "C" __declspec(dllimport)
   #endif
#else
   #define MPDH8USB_TCP_API
#endif
#define TKCMDSET_MAC_ADDR_LEN       6


/* MPD Standard data type definitions */
#ifndef MPD_TYPES
#define MPD_TYPES
typedef unsigned char  UINT8_T;
typedef unsigned short UINT16_T;
typedef unsigned long  UINT32_T;
typedef char           INT8_T;
typedef short          INT16_T;
typedef long           INT32_T;
typedef unsigned char  BOOLEAN_T;
typedef float          FLOAT32_T;
typedef INT16_T        ERRCODE_T;
#endif

/* Lighthead channel data structure */
typedef struct
{
   FLOAT32_T led_r_th;                  /* Degrees C, LED Thermal resistance */
   FLOAT32_T tau;                       /* Seconds, Thermal time constant */
   FLOAT32_T led_voltage_slope;         /* No units, scale factor to calculate LED Vf */
   FLOAT32_T led_voltage_offset;        /* Volts, offset used to calculate LED Vf */
   FLOAT32_T max_junct_temp;            /* Degrees C, Maximum junction temperature */
   UINT32_T  num_str;                   /* Number of strings per channel */
   UINT32_T  num_led;                   /* Number of LEDs per string */
   FLOAT32_T hs_r_th;                   /* Degree C, Heatsink Thermal resistance */
   FLOAT32_T default_current;           /* Amps, default LED current */
   FLOAT32_T max_pulse_current;         /* Amps, maximum LED current in pulse mode */
   FLOAT32_T max_cont_current;          /* Amps, maximum LED current in continuous mode */
   FLOAT32_T reserved[4];               /* Reserved for future expansion */
} TKCMDSET_LH_CHAN_STRUCT_T;            /* 60 bytes total */

/* Lighthead data structure */
typedef struct
{
  UINT8_T  part_number[16];             /* Part number string */
  UINT8_T  mfg_date[20];                /* Manufacturing date string */
  UINT8_T  reserved[100];               /* Reserved for future expansion */
  TKCMDSET_LH_CHAN_STRUCT_T chan[4];    /* 240 bytes of channel info */
} TKCMDSET_LIGHTHEAD_STRUCT_T;          /* 376 bytes total */

/* Definitions for the USB identifier strings */
#define TKCMDSET_H8_PRODUCT_NAME            "Ai Pulsar 320 Controller"

#define TKCMDSET_PROGRESS_MESSAGE            (WM_USER + 100)
#define TKCMDSET_WRITE_RAM_DATA              1
#define TKCMDSET_READ_RAM_DATA               2
#define TKCMDSET_WRITE_FLASH_DATA            3
#define TKCMDSET_READ_FLASH_DATA             4
#define TKCMDSET_WRITE_EE_DATA               5
#define TKCMDSET_READ_EE_DATA                6


#define TKCMDSET_START_LOADER_FEATURE        101
#define TKCMDSET_START_APPLICATION_FEATURE   102
#define TKCMDSET_RESET_FEATURE               103

/********************************************************************************
   Prototypes for standard DLL functions
********************************************************************************/


/****************************************************************************
   tkcmdset_get_dll_version()

   Returns the current version number of this software.

   Inputs:     None

   Outputs:    None
   
   Returns:    UINT16_T    ver_info    High byte is major version number
                                       Low byte is minor version number

****************************************************************************/
MPDH8USB_TCP_API UINT16_T tkcmdset_get_dll_version(void);

/****************************************************************************
   tkcmdset_get_error_name

   About:      Returns the name of the error associated with the code

   Inputs:     ERRCODE_T   ecode       Code to be looked up
               UINT16_T    namelen     Maximum length of name string

   Outputs:    char *      nameptr     Location to place name string

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_get_error_name(ERRCODE_T ecode,char * nameptr,UINT16_T namelen);

/****************************************************************************
   tkcmdset_get_error_text

   About:      Returns the text description of the error associated with the code

   Inputs:     ERRCODE_T   ecode       Code to be looked up
               UINT16_T    namelen     Maximum length of text description string

   Outputs:    char *      nameptr     Location to place text description string

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_get_error_text(ERRCODE_T ecode,char * textptr,UINT16_T textlen);



/********************************************************************************
   Prototypes for Command Set functions
********************************************************************************/


/****************************************************************************
   tkcmdset_init_ex

   About:      Initializes the Command Set Toolkit functions
               Extended to indicate this DLL supports 32-bit pulse widths.

   Inputs:     UINT8_T     port        Communication port to use
               INT8_T *    product_name Name of USB device to open
               INT8_T *    serial_num  Serial number of device to open

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_init_ex(UINT8_T port, INT8_T *product_name, INT8_T *serial_num);

/****************************************************************************
   tkcmdset_connect

   About:      Initializes the Command Set Toolkit functions
               Extended to indicate this DLL supports 32-bit pulse widths.

   Inputs:     UINT8_T     port         Communication port to use
               INT8_T *    product_name Name of USB device to open
               INT8_T *   ip_addr		IP address of device to open	

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_connect(UINT8_T port, INT8_T * product_name, INT8_T * ip_addr);


/****************************************************************************
   tkcmdset_set_feature

   About:      Sends a USB SetFeature Standard Request to the device
               This is independent of the command / response protocol

   Inputs:     UINT8_T     port        Communication port to use
               UINT16_T    feature     Identifier for desired feature to activate

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_set_feature(UINT8_T port, UINT16_T feature);

/****************************************************************************
   tkcmdset_echo

   About:      Send and receive a data block, no action taken by device

   Inputs:     UINT8_T     port        Identifier for device
               UINT8_T *   cmd_ptr     Location of data to send to device

   Outputs:    UINT8_T *   rsp_ptr     Location to store data returned by device

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_echo(UINT8_T port, UINT8_T * cmd_ptr, UINT8_T * rsp_ptr);

/****************************************************************************
   tkcmdset_fw_version

   About:      Reads firmware version information from the device

   Inputs:     UINT8_T     port        Identifier for device

   Outputs:    UINT8_T *   ver_ptr     FW version string stored at this location

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_fw_version(UINT8_T port, UINT8_T *ver_ptr);

/****************************************************************************
   tkcmdset_hw_version

   About:      Reads hardware version information from the device

   Inputs:     UINT8_T     port        Identifier for device

   Outputs:    UINT8_T *   ver_ptr     HW version string stored at this location

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_hw_version(UINT8_T port, UINT8_T *ver_ptr);

/****************************************************************************
   tkcmdset_serial_number

   About:      Reads the serial number information from the device

   Inputs:     UINT8_T     port        Identifier for device

   Outputs:    UINT8_T *   ser_ptr     Serial number string stored at this location

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_serial_number(UINT8_T port, UINT8_T *ser_ptr);

/****************************************************************************
   tkcmdset_status

   About:      Reads status information from the device

   Inputs:     UINT8_T     port        Identifier for device

   Outputs:    UINT32_T *  stat_ptr    Location to store status information

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_status(UINT8_T port, UINT16_T *stat_ptr);

/****************************************************************************
   tkcmdset_run_diags

   About:      Runs one or all of the built in diagnostics

   Inputs:     UINT8_T     port        Identifier for device
               UINT8_T     test_num    Desired test number or FF for all

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_run_diags(UINT8_T port, UINT8_T test_num);

/****************************************************************************
   tkcmdset_special

   About:      Performs special operations based on the command

   Inputs:     UINT8_T     port        Identifier for device
               UINT16_T    cmd         Special command to execute
               UINT32_T    in_data     Value send with command

   Outputs:    UINT32_T *  out_data    Location to store value returned
                                       with response

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_special(UINT8_T port, UINT16_T cmd, UINT32_T in_data, UINT32_T *out_data);

/****************************************************************************
   tkcmdset_set_an_out

   About:   Controls an analog output
   
   Inputs:  UINT8_T  port       Identifier for device
            UINT16_T chan       Channel number of output
            UINT16_T val        Value to be set

   Outputs: ERRCODE_T   ecode   Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_set_an_out(UINT8_T port, UINT16_T chan, UINT16_T val);

/****************************************************************************
   tkcmdset_get_an_out

   About:   Reads the last value loaded on an analog output
   
   Inputs:  UINT8_T  port       Identifier for device
            UINT16_T chan       Channel number of output
   
   Outputs: UINT16_T *val       Last value loaded

   Returns: ERRCODE_T   ecode   Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_get_an_out(UINT8_T port, UINT16_T chan, UINT16_T *val);

/****************************************************************************
   tkcmdset_get_an_in

   About:      Reads the current value on an analog input channel
   
   Inputs:  UINT8_T  port       Identifier for device
            UINT16_T chan       Channel number of the input

   Outputs: INT16_T *val        Current value of analog input

   Returns: ERRCODE_T   ecode   Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_get_an_in(UINT8_T port, UINT16_T chan, INT16_T *val);

/****************************************************************************
   tkcmdset_get_volts

   About:      Returns the voltage for the specified analog input channel
               in engineering units.
   
   Inputs:  UINT8_T  port       Identifier for device
            UINT16_T chan       Channel number of the input

   Outputs: FLOAT32_T *val      Analog voltage

   Returns: ERRCODE_T   ecode   Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_get_volts(UINT8_T port, UINT16_T chan, FLOAT32_T *val);

/****************************************************************************
   tkcmdset_set_dig_out

   About:   Controls a digital output channel
   
   Inputs:  UINT8_T   port       Identifier for device
            UINT16_T  chan       Channel number of the output
            BOOLEAN_T state      TRUE / FALSE state of output

   Outputs: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_set_dig_out(UINT8_T port, UINT16_T chan, BOOLEAN state);

/****************************************************************************
   tkcmdset_get_dig_out

   About:   Reads the last value loaded on a digital output
   
   Inputs:  UINT8_T  port       Identifier for device
            UINT16_T chan       Channel number of the output
            BOOLEAN *state      TRUE / FALSE state of the output

   Outputs: ERRCODE_T   ecode   Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_get_dig_out(UINT8_T port, UINT16_T chan, BOOLEAN *state);

/****************************************************************************
   tkcmdset_get_dig_in

   About:   Reads the current value of a digital input
   
   Inputs:  UINT8_T  port       Identifier for device
            UINT16_T chan       Channel number of the input
            BOOLEAN *state      TRUE / FALSE state of the input

   Outputs: ERRCODE_T   ecode   Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_get_dig_in(UINT8_T port, UINT16_T chan, BOOLEAN *state);

/****************************************************************************
   tkcmdset_write_mem

   About:   Writes a 8-bit value to memory
   
   Inputs:  UINT8_T  port       Identifier for device
            UINT32_T addr       Address to write
            UINT8_T val         Value to be written

   Outputs: ERRCODE_T   ecode   Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_write_mem(UINT8_T port, UINT32_T addr, UINT8_T val);

/****************************************************************************
   tkcmdset_read_mem

   About:   Reads a 8-bit value from local memory
   
   Inputs:  UINT8_T  port       Identifier for device
            UINT32_T addr       Address to read
            UINT8_T *val        Current value

   Outputs: ERRCODE_T   ecode   Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_read_mem(UINT8_T port, UINT32_T addr, UINT8_T *val);

/****************************************************************************
   tkcmdset_write_mem_block

   About:   Writes block of values to local memory
   
   Inputs:  UINT8_T  port       Identifier for device
            UINT32_T addr       Address to write
            UINT8_T  *val       Location of values to be written
            UINT16_T slen       Number of bytes to be written

   Outputs: ERRCODE_T   ecode   Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_write_mem_block(UINT8_T port, UINT32_T addr, UINT8_T *val, UINT16_T len);

/****************************************************************************
   tkcmdset_read_mem_block

   About:      Reads a block of values from local memory
   
   Inputs:  UINT8_T  port       Identifier for device
            UINT32_T addr       Address to read
            UINT8_T  *val       Location where values should be stored
            UINT16_T slen       Number of bytes to read

   Outputs: ERRCODE_T   ecode   Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_read_mem_block(UINT8_T port, UINT32_T addr, UINT8_T *val, UINT16_T len);

/****************************************************************************
   tkcmdset_write_eemem_block

   About:      Writes block of values to external EE memory
   
   Inputs:  UINT8_T  port       Identifier for device
            UINT16_T addr       Address in EEPROM to write
            UINT8_T  *val       Location of values to be written
            UINT16_T slen       Number of bytes to be written

   Outputs: ERRCODE_T   ecode   Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_write_eemem_block(UINT8_T port, UINT16_T addr, UINT8_T *val, UINT16_T len);

/****************************************************************************
   tkcmdset_read_eemem_block

   About:      Reads a block of values from external EE memory
   
   Inputs:  UINT8_T  port       Identifier for device
            UINT16_T addr       Address in EEPROM to read
            UINT16_T *val       Location where values should be stored
            UINT16_T slen       Number of bytes to read

   Outputs: ERRCODE_T   ecode   Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_read_eemem_block(UINT8_T port, UINT16_T addr, UINT8_T *val, UINT16_T len);

/****************************************************************************
   tkcmdset_execute

   About:      Causes the code to execute a function call to the specified address

   Inputs:     UINT8_T     port        Identifier for device
               UINT32_T    addr        Address of function
               UINT32_T    in_data     Value passed to function

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_execute(UINT8_T port, UINT32_T addr);

/****************************************************************************
   tkcmdset_set_pulse

   About:   Configures pulse characteristics for the selected drive channels
   
   Inputs:  UINT8_T   port       Identifier for device
            UINT8_T   chan       Bitmask of selected drive channels
            UINT32_T  width      Pulse width in microseconds
            UINT16_T  delay      Pulse delay in microseconds
            FLOAT32_T current    Pulse current in amps

   Outputs: None
   
   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_set_pulse(UINT8_T port, UINT8_T chan, 
                                            UINT32_T width, UINT16_T delay, FLOAT32_T current);

/****************************************************************************
   tkcmdset_get_pulse

   About:   Retrieves pulse characteristics for the selected drive channel
   
   Inputs:  UINT8_T    port      Identifier for device
            UINT8_T    chan      Selected drive channel
   
   Outputs: UINT32_T*  width     Active pulse width in microseconds
            UINT16_T*  delay     Active pulse delay in microseconds
            FLOAT32_T* current   Active pulse current in amps

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_get_pulse(UINT8_T port, UINT8_T chan, 
                                            UINT32_T* width, UINT16_T* delay, FLOAT32_T* current);

/****************************************************************************
   tkcmdset_set_repeat

   About:   Configures pulse repeat characteristics for the selected drive channels
   
   Inputs:  UINT8_T   port       Identifier for device
            UINT8_T   chan       Bitmask of selected drive channels
            UINT32_T  offtime    Off time between pulses
            UINT16_T  count      Number of pulses per trigger

   Outputs: None
   
   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_set_repeat(UINT8_T port, UINT8_T chan, 
                                                UINT32_T offtime, UINT16_T count);

/****************************************************************************
   tkcmdset_get_repeat

   About:   Retrieves pulse characteristics for the selected drive channel
   
   Inputs:  UINT8_T    port      Identifier for device
            UINT8_T    chan      Selected drive channel
   
   Outputs: UINT32_T*  offtime   Active off time between pulsesi n microseconds
            UINT16_T*  count     Active number of pulses per trigger

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_get_repeat(UINT8_T port, UINT8_T chan, 
                                                 UINT32_T* offtime, UINT16_T* count);

/****************************************************************************
   tkcmdset_set_trigger_map

   About:   Configures trigger characteristics for the selected trigger channel.
            This function is used in pulse mode only.
            A trigger can be mapped to multiple drive channels.
   
   Inputs:  UINT8_T   port       Identifier for device
            UINT8_T   trig       Selected trigger channel
            UINT8_T   chan       Bitmask of selected drive channels
            UINT8_T   rising     TRUE for rising edge triggers

   Outputs: None
   
   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_set_trigger_map(UINT8_T port, UINT8_T trig, UINT8_T chan, UINT8_T rising);

/****************************************************************************
   tkcmdset_set_gate_map

   About:   Configures gate characteristics for the selected channel.
            This function is used in continuous mode only.
            A gate can be mapped to multiple drive channels.
   
   Inputs:  UINT8_T   port       Identifier for device
            UINT8_T   gate       Selected gate channel
            UINT8_T   chan       Bitmask of selected drive channels
            UINT8_T   rising     TRUE for rising edge triggers

   Outputs: None
   
   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_set_gate_map(UINT8_T port, UINT8_T gate, UINT8_T chan, UINT8_T rising);

/****************************************************************************
   tkcmdset_get_trigger_map

   About:   Retrieves trigger characteristics for the selected trigger channel
   
   Inputs:  UINT8_T    port      Identifier for device
            UINT8_T    trig      Selected trigger channel
   
   Outputs: UINT8_T*   chan      Active channel bitmask for this trigger
            UINT8_T*   rising    TRUE if rising edge triggered

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_get_trigger_map(UINT8_T port, UINT8_T trig, UINT8_T* chan, UINT8_T* rising);

/****************************************************************************
   tkcmdset_set_hv_supply

   About:   Adjusts the setpoint the High Voltage String Supply for the specified channels
   
   Inputs:  UINT8_T   port       Identifier for device
            UINT8_T   chan       Bitmask of channels to set voltage
            FLOAT32_T voltage    Desired voltage of HV Supply

   Outputs: None
   
   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_set_hv_supply(UINT8_T port, UINT8_T chan, FLOAT32_T voltage);

/****************************************************************************
   tkcmdset_get_hv_supply

   About:   Retrieves the active setpoint a channel or the High Voltage String Supply
   
   Inputs:  UINT8_T    port      Identifier for device
            UINT8_T    chan      Desired channel voltage to get, zero for actual supply voltage

   Outputs: FLOAT32_T *voltage   Active HV Supply voltage

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_get_hv_supply(UINT8_T port, UINT8_T chan, FLOAT32_T *voltage);

/****************************************************************************
   tkcmdset_set_lv_supply

   About:   Adjusts the setpoint the Low Voltage String Supply for the specified channels
   
   Inputs:  UINT8_T   port       Identifier for device
            UINT8_T   chan       Bitmask of channels to set voltage
            FLOAT32_T voltage    Desired voltage of LV Supply

   Outputs: None
   
   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_set_lv_supply(UINT8_T port, UINT8_T chan, FLOAT32_T voltage);

/****************************************************************************
   tkcmdset_get_lv_supply

   About:   Retrieves the active setpoint a channel or the Low Voltage String Supply
   
   Inputs:  UINT8_T    port      Identifier for device
            UINT8_T    chan      Desired channel voltage to get, zero for actual supply voltage

   Outputs: FLOAT32_T *voltage   Active LV Supply voltage

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_get_lv_supply(UINT8_T port, UINT8_T chan, FLOAT32_T *voltage);

/****************************************************************************
   tkcmdset_trigger

   About:   Generates a software trigger on the selected trigger channels
   
   Inputs:  UINT8_T   port       Identifier for device
            UINT8_T   trig       Bitmask of triggers to activate

   Outputs: None
   
   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_trigger(UINT8_T port, UINT8_T trig);

/****************************************************************************
   tkcmdset_set_pulse_out

   About:   Sets the state of multiple pulse channel outputs
   
   Inputs:  UINT8_T   port       Identifier for device
            UINT8_T   chan       Bitmask of channels to set
            BOOLEAN_T state      Desired state of outputs

   Outputs: None
   
   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_set_pulse_out(UINT8_T port, UINT8_T chan, BOOLEAN_T state);

/****************************************************************************
   tkcmdset_get_pulse_out

   About:   Gets the state of a pulse channel output
   
   Inputs:  UINT8_T   port       Identifier for device
            UINT8_T   chan       Channel to get
            
   Outputs: BOOLEAN_T *state     Location to store state of channel
   
   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T   tkcmdset_get_pulse_out(UINT8_T port, UINT8_T chan, BOOLEAN_T *state);

/*******************************************************************************
   tkcmdset_calc_led_temp

   About:   Calculates the expected LED junction temperature based on the
            information stored in the lighthead data structure and the width
            and current information passed.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute LED temperature
            UINT32_T    width       Pulse width in microseconds
            FLOAT32_T   current     Pulse current in amps
   
   Outputs: FLOAT32_T  *temp        Location to store calculated temperature

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
********************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_calc_led_temp(UINT8_T port, UINT8_T ch, 
                                              UINT32_T width, FLOAT32_T current, FLOAT32_T *temp);

/*******************************************************************************
   tkcmdset_calc_max_width

   About:   Calculates the maximum pulse width for the selected channel based 
            on the information stored in the lighthead data structure and the 
            current information passed.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute LED temperature
            FLOAT32_T   current     Pulse current in amps
   
   Outputs: UINT32_T   *width       Maximum pulse width in microseconds

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
********************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_calc_max_width(UINT8_T port, UINT8_T ch, 
                                               FLOAT32_T current, UINT32_T * width);

/*******************************************************************************
   tkcmdset_calc_max_current

   About:   Calculates the maximum pulse current for the selected channel based 
            on the information stored in the lighthead data structure and the 
            width information passed.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute LED temperature
            UINT32_T    width       Pulse width in microseconds
   
   Outputs: FLOAT32_T  *current     Maximum pulse current in amps

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
********************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_calc_max_current(UINT8_T port, UINT8_T ch, 
                                                 UINT32_T width, FLOAT32_T *current);

/*******************************************************************************
   tkcmdset_calc_supply_voltage

   About:   Calculates the required supply voltage for a given width and current.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute required supply voltage
            UINT32_T    width       Pulse width in microseconds
            FLOAT32_T   current     Pulse current in amps
   
   Outputs: FLOAT32_T  *voltage     Location to store calculated voltage

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
********************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_calc_supply_voltage(UINT8_T port, UINT8_T ch, 
                                                    UINT32_T width, FLOAT32_T current, FLOAT32_T *voltage);

/*******************************************************************************
   tkcmdset_calc_max_freq

   About:   Calculates the maximum frequency allowed for a given width and current.
            This function computes maximum frequency based on the maximum power of
            the power supply and also from the LED cooling equations.  The lower
            value is returned.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute maximum frequency
            UINT32_T    width       Pulse width in microseconds
            FLOAT32_T   current     Pulse current in amps
   
   Outputs: UINT16_T   *freq        Location to store calculated frequency

   Returns: ERRCODE_T ecode      Status of command
                                   Zero if successful,
                                   Error code otherwise
  
********************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_calc_max_freq(UINT8_T port, UINT8_T ch, 
                                              UINT32_T width, FLOAT32_T current, UINT16_T *freq);

/****************************************************************************
   tkcmdset_set_lighthead_data

   About:      Loads the supplied data into the lighthead EEPROM

   Inputs:     UINT8_T     port        Communication port to use
               TKCMDSET_LIGHTHEAD_STRUCT_T * lh_data
                                       All lighthead data

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_set_lighthead_data(UINT8_T port,
                                                   TKCMDSET_LIGHTHEAD_STRUCT_T * lh_info);

/****************************************************************************
   tkcmdset_get_lighthead_data

   About:      Retrieves the data from the lighthead EEPROM

   Inputs:     UINT8_T     port        Communication port to use
               
   Outputs:    TKCMDSET_LIGHTHEAD_STRUCT_T * lh_data
                                       All lighthead data

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_get_lighthead_data(UINT8_T port,
                                                   TKCMDSET_LIGHTHEAD_STRUCT_T * lh_info);

/****************************************************************************
   tkcmdset_set_ip

   About:      Sets the current IP address

   Inputs:     UINT32_T    ip          IP address
               UINT32_T    subnet      Subnet address
               UINT32_T    gateway     Gateway address

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_set_ip(UINT8_T port,UINT32_T ip,UINT32_T subnet,UINT32_T gateway);

/****************************************************************************
   tkcmdset_get_ip

   About:      Retrieves the current IP address of the unit

   Inputs:     None
               
   Outputs:    UINT32_T*   ip          IP address
               UINT32_T*   subnet      Subnet address
               UINT32_T*   gateway     Gateway address

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_get_ip(UINT8_T port, UINT32_T* ip, UINT32_T* subnet,UINT32_T* gateway);

/****************************************************************************
   tkcmdset_set_mac

   About:      Sets the current MAC address of the unit

   Inputs:     UINT8_T*    mac_addr    6-byte array containing 48-bit MAC
               
   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_set_mac(UINT8_T port, UINT8_T* mac_addr);

/****************************************************************************
   tkcmdset_get_mac

   About:      Retrieves the current MAC address of the unit

   Inputs:     None
               
   Outputs:    UINT8_T*    mac_addr    6-byte array to contain 48-bit MAC

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_get_mac(UINT8_T port, UINT8_T* mac_addr);

/****************************************************************************
   tkcmdset_shutdown

   About:      Shuts down the Command Set Toolkit functions

   Inputs:     UINT8_T     port        Communication port to use

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
MPDH8USB_TCP_API ERRCODE_T tkcmdset_shutdown(UINT8_T port);

#endif /* MPDH8USB_TCP */


